@@ -10,15 +10,38 @@ import publication
 
 from .._jsii import *
 
-from .. import (Construct as _Construct_f50a3f53, Stack as _Stack_05f4505a)
-from ..aws_cloudformation import (CloudFormationCapabilities as _CloudFormationCapabilities_979dd343)
-from ..aws_codepipeline import (ActionConfig as _ActionConfig_c379766c, IStage as _IStage_b7c853a7, ActionBindOptions as _ActionBindOptions_530c352f, ActionProperties as _ActionProperties_8f5d7a9d, IAction as _IAction_369e77ae, Artifact as _Artifact_af6d98e9)
-from ..aws_events import (Rule as _Rule_c38e0b39, IRuleTarget as _IRuleTarget_41800a77, RuleProps as _RuleProps_d60f0abf)
-from ..aws_iam import (PolicyStatement as _PolicyStatement_f75dc775, IRole as _IRole_e69bbae4)
+from .. import Stack as _Stack_05f4505a, Construct as _Construct_f50a3f53
+from ..aws_cloudformation import (
+    CloudFormationCapabilities as _CloudFormationCapabilities_979dd343,
+)
+from ..aws_codepipeline import (
+    Artifact as _Artifact_af6d98e9,
+    ActionConfig as _ActionConfig_c379766c,
+    IStage as _IStage_b7c853a7,
+    ActionBindOptions as _ActionBindOptions_530c352f,
+    ActionProperties as _ActionProperties_8f5d7a9d,
+    IAction as _IAction_369e77ae,
+)
+from ..aws_events import (
+    Rule as _Rule_c38e0b39,
+    IRuleTarget as _IRuleTarget_41800a77,
+    RuleProps as _RuleProps_d60f0abf,
+    IEventBus as _IEventBus_ed4f1700,
+    EventPattern as _EventPattern_8aa7b781,
+    Schedule as _Schedule_11a70620,
+)
+from ..aws_iam import (
+    IRole as _IRole_e69bbae4,
+    PolicyStatement as _PolicyStatement_f75dc775,
+)
+from ..aws_s3 import IBucket as _IBucket_25bad983
 
 
 @jsii.implements(_IAction_369e77ae)
-class PipelineDeployStackAction(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.app_delivery.PipelineDeployStackAction"):
+class PipelineDeployStackAction(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.app_delivery.PipelineDeployStackAction",
+):
     """A class to deploy a stack that is part of a CDK App, using CodePipeline.
 
     This composite Action takes care of preparing and executing a CloudFormation ChangeSet.
@@ -30,7 +53,23 @@ class PipelineDeployStackAction(metaclass=jsii.JSIIMeta, jsii_type="monocdk-expe
     stability
     :stability: experimental
     """
-    def __init__(self, *, admin_permissions: bool, input: _Artifact_af6d98e9, stack: _Stack_05f4505a, capabilities: typing.Optional[typing.List[_CloudFormationCapabilities_979dd343]]=None, change_set_name: typing.Optional[str]=None, create_change_set_action_name: typing.Optional[str]=None, create_change_set_run_order: typing.Optional[jsii.Number]=None, execute_change_set_action_name: typing.Optional[str]=None, execute_change_set_run_order: typing.Optional[jsii.Number]=None, role: typing.Optional[_IRole_e69bbae4]=None) -> None:
+
+    def __init__(
+        self,
+        *,
+        admin_permissions: bool,
+        input: _Artifact_af6d98e9,
+        stack: _Stack_05f4505a,
+        capabilities: typing.Optional[
+            typing.List[_CloudFormationCapabilities_979dd343]
+        ] = None,
+        change_set_name: typing.Optional[str] = None,
+        create_change_set_action_name: typing.Optional[str] = None,
+        create_change_set_run_order: typing.Optional[jsii.Number] = None,
+        execute_change_set_action_name: typing.Optional[str] = None,
+        execute_change_set_run_order: typing.Optional[jsii.Number] = None,
+        role: typing.Optional[_IRole_e69bbae4] = None,
+    ) -> None:
         """
         :param admin_permissions: Whether to grant admin permissions to CloudFormation while deploying this template. Setting this to ``true`` affects the defaults for ``role`` and ``capabilities``, if you don't specify any alternatives. The default role that will be created for you will have admin (i.e., ``*``) permissions on all resources, and the deployment will have named IAM capabilities (i.e., able to create all IAM resources). This is a shorthand that you can use if you fully trust the templates that are deployed in this pipeline. If you want more fine-grained permissions, use ``addToRolePolicy`` and ``capabilities`` to control what the CloudFormation deployment is allowed to do.
         :param input: The CodePipeline artifact that holds the synthesized app, which is the contents of the ``<directory>`` when running ``cdk synth -o <directory>``.
@@ -46,12 +85,25 @@ class PipelineDeployStackAction(metaclass=jsii.JSIIMeta, jsii_type="monocdk-expe
         stability
         :stability: experimental
         """
-        props = PipelineDeployStackActionProps(admin_permissions=admin_permissions, input=input, stack=stack, capabilities=capabilities, change_set_name=change_set_name, create_change_set_action_name=create_change_set_action_name, create_change_set_run_order=create_change_set_run_order, execute_change_set_action_name=execute_change_set_action_name, execute_change_set_run_order=execute_change_set_run_order, role=role)
+        props = PipelineDeployStackActionProps(
+            admin_permissions=admin_permissions,
+            input=input,
+            stack=stack,
+            capabilities=capabilities,
+            change_set_name=change_set_name,
+            create_change_set_action_name=create_change_set_action_name,
+            create_change_set_run_order=create_change_set_run_order,
+            execute_change_set_action_name=execute_change_set_action_name,
+            execute_change_set_run_order=execute_change_set_run_order,
+            role=role,
+        )
 
         jsii.create(PipelineDeployStackAction, self, [props])
 
     @jsii.member(jsii_name="addToDeploymentRolePolicy")
-    def add_to_deployment_role_policy(self, statement: _PolicyStatement_f75dc775) -> None:
+    def add_to_deployment_role_policy(
+        self, statement: _PolicyStatement_f75dc775
+    ) -> None:
         """Add policy statements to the role deploying the stack.
 
         This role is passed to CloudFormation and must have the IAM permissions
@@ -68,7 +120,14 @@ class PipelineDeployStackAction(metaclass=jsii.JSIIMeta, jsii_type="monocdk-expe
         return jsii.invoke(self, "addToDeploymentRolePolicy", [statement])
 
     @jsii.member(jsii_name="bind")
-    def bind(self, scope: _Construct_f50a3f53, stage: _IStage_b7c853a7, *, bucket: _IBucket_25bad983, role: _IRole_e69bbae4) -> _ActionConfig_c379766c:
+    def bind(
+        self,
+        scope: _Construct_f50a3f53,
+        stage: _IStage_b7c853a7,
+        *,
+        bucket: _IBucket_25bad983,
+        role: _IRole_e69bbae4,
+    ) -> _ActionConfig_c379766c:
         """
         :param scope: -
         :param stage: -
@@ -83,7 +142,19 @@ class PipelineDeployStackAction(metaclass=jsii.JSIIMeta, jsii_type="monocdk-expe
         return jsii.invoke(self, "bind", [scope, stage, options])
 
     @jsii.member(jsii_name="onStateChange")
-    def on_state_change(self, name: str, target: typing.Optional[_IRuleTarget_41800a77]=None, *, description: typing.Optional[str]=None, enabled: typing.Optional[bool]=None, event_bus: typing.Optional[_IEventBus_ed4f1700]=None, event_pattern: typing.Optional[_EventPattern_8aa7b781]=None, rule_name: typing.Optional[str]=None, schedule: typing.Optional[_Schedule_11a70620]=None, targets: typing.Optional[typing.List[_IRuleTarget_41800a77]]=None) -> _Rule_c38e0b39:
+    def on_state_change(
+        self,
+        name: str,
+        target: typing.Optional[_IRuleTarget_41800a77] = None,
+        *,
+        description: typing.Optional[str] = None,
+        enabled: typing.Optional[bool] = None,
+        event_bus: typing.Optional[_IEventBus_ed4f1700] = None,
+        event_pattern: typing.Optional[_EventPattern_8aa7b781] = None,
+        rule_name: typing.Optional[str] = None,
+        schedule: typing.Optional[_Schedule_11a70620] = None,
+        targets: typing.Optional[typing.List[_IRuleTarget_41800a77]] = None,
+    ) -> _Rule_c38e0b39:
         """
         :param name: -
         :param target: -
@@ -98,7 +169,15 @@ class PipelineDeployStackAction(metaclass=jsii.JSIIMeta, jsii_type="monocdk-expe
         stability
         :stability: experimental
         """
-        options = _RuleProps_d60f0abf(description=description, enabled=enabled, event_bus=event_bus, event_pattern=event_pattern, rule_name=rule_name, schedule=schedule, targets=targets)
+        options = _RuleProps_d60f0abf(
+            description=description,
+            enabled=enabled,
+            event_bus=event_bus,
+            event_pattern=event_pattern,
+            rule_name=rule_name,
+            schedule=schedule,
+            targets=targets,
+        )
 
         return jsii.invoke(self, "onStateChange", [name, target, options])
 
@@ -121,9 +200,39 @@ class PipelineDeployStackAction(metaclass=jsii.JSIIMeta, jsii_type="monocdk-expe
         return jsii.get(self, "deploymentRole")
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.app_delivery.PipelineDeployStackActionProps", jsii_struct_bases=[], name_mapping={'admin_permissions': 'adminPermissions', 'input': 'input', 'stack': 'stack', 'capabilities': 'capabilities', 'change_set_name': 'changeSetName', 'create_change_set_action_name': 'createChangeSetActionName', 'create_change_set_run_order': 'createChangeSetRunOrder', 'execute_change_set_action_name': 'executeChangeSetActionName', 'execute_change_set_run_order': 'executeChangeSetRunOrder', 'role': 'role'})
-class PipelineDeployStackActionProps():
-    def __init__(self, *, admin_permissions: bool, input: _Artifact_af6d98e9, stack: _Stack_05f4505a, capabilities: typing.Optional[typing.List[_CloudFormationCapabilities_979dd343]]=None, change_set_name: typing.Optional[str]=None, create_change_set_action_name: typing.Optional[str]=None, create_change_set_run_order: typing.Optional[jsii.Number]=None, execute_change_set_action_name: typing.Optional[str]=None, execute_change_set_run_order: typing.Optional[jsii.Number]=None, role: typing.Optional[_IRole_e69bbae4]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.app_delivery.PipelineDeployStackActionProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "admin_permissions": "adminPermissions",
+        "input": "input",
+        "stack": "stack",
+        "capabilities": "capabilities",
+        "change_set_name": "changeSetName",
+        "create_change_set_action_name": "createChangeSetActionName",
+        "create_change_set_run_order": "createChangeSetRunOrder",
+        "execute_change_set_action_name": "executeChangeSetActionName",
+        "execute_change_set_run_order": "executeChangeSetRunOrder",
+        "role": "role",
+    },
+)
+class PipelineDeployStackActionProps:
+    def __init__(
+        self,
+        *,
+        admin_permissions: bool,
+        input: _Artifact_af6d98e9,
+        stack: _Stack_05f4505a,
+        capabilities: typing.Optional[
+            typing.List[_CloudFormationCapabilities_979dd343]
+        ] = None,
+        change_set_name: typing.Optional[str] = None,
+        create_change_set_action_name: typing.Optional[str] = None,
+        create_change_set_run_order: typing.Optional[jsii.Number] = None,
+        execute_change_set_action_name: typing.Optional[str] = None,
+        execute_change_set_run_order: typing.Optional[jsii.Number] = None,
+        role: typing.Optional[_IRole_e69bbae4] = None,
+    ) -> None:
         """
         :param admin_permissions: Whether to grant admin permissions to CloudFormation while deploying this template. Setting this to ``true`` affects the defaults for ``role`` and ``capabilities``, if you don't specify any alternatives. The default role that will be created for you will have admin (i.e., ``*``) permissions on all resources, and the deployment will have named IAM capabilities (i.e., able to create all IAM resources). This is a shorthand that you can use if you fully trust the templates that are deployed in this pipeline. If you want more fine-grained permissions, use ``addToRolePolicy`` and ``capabilities`` to control what the CloudFormation deployment is allowed to do.
         :param input: The CodePipeline artifact that holds the synthesized app, which is the contents of the ``<directory>`` when running ``cdk synth -o <directory>``.
@@ -140,17 +249,28 @@ class PipelineDeployStackActionProps():
         :stability: experimental
         """
         self._values = {
-            'admin_permissions': admin_permissions,
-            'input': input,
-            'stack': stack,
+            "admin_permissions": admin_permissions,
+            "input": input,
+            "stack": stack,
         }
-        if capabilities is not None: self._values["capabilities"] = capabilities
-        if change_set_name is not None: self._values["change_set_name"] = change_set_name
-        if create_change_set_action_name is not None: self._values["create_change_set_action_name"] = create_change_set_action_name
-        if create_change_set_run_order is not None: self._values["create_change_set_run_order"] = create_change_set_run_order
-        if execute_change_set_action_name is not None: self._values["execute_change_set_action_name"] = execute_change_set_action_name
-        if execute_change_set_run_order is not None: self._values["execute_change_set_run_order"] = execute_change_set_run_order
-        if role is not None: self._values["role"] = role
+        if capabilities is not None:
+            self._values["capabilities"] = capabilities
+        if change_set_name is not None:
+            self._values["change_set_name"] = change_set_name
+        if create_change_set_action_name is not None:
+            self._values[
+                "create_change_set_action_name"
+            ] = create_change_set_action_name
+        if create_change_set_run_order is not None:
+            self._values["create_change_set_run_order"] = create_change_set_run_order
+        if execute_change_set_action_name is not None:
+            self._values[
+                "execute_change_set_action_name"
+            ] = execute_change_set_action_name
+        if execute_change_set_run_order is not None:
+            self._values["execute_change_set_run_order"] = execute_change_set_run_order
+        if role is not None:
+            self._values["role"] = role
 
     @builtins.property
     def admin_permissions(self) -> bool:
@@ -171,7 +291,7 @@ class PipelineDeployStackActionProps():
         stability
         :stability: experimental
         """
-        return self._values.get('admin_permissions')
+        return self._values.get("admin_permissions")
 
     @builtins.property
     def input(self) -> _Artifact_af6d98e9:
@@ -180,7 +300,7 @@ class PipelineDeployStackActionProps():
         stability
         :stability: experimental
         """
-        return self._values.get('input')
+        return self._values.get("input")
 
     @builtins.property
     def stack(self) -> _Stack_05f4505a:
@@ -189,10 +309,12 @@ class PipelineDeployStackActionProps():
         stability
         :stability: experimental
         """
-        return self._values.get('stack')
+        return self._values.get("stack")
 
     @builtins.property
-    def capabilities(self) -> typing.Optional[typing.List[_CloudFormationCapabilities_979dd343]]:
+    def capabilities(
+        self,
+    ) -> typing.Optional[typing.List[_CloudFormationCapabilities_979dd343]]:
         """Acknowledge certain changes made as part of deployment.
 
         For stacks that contain certain resources, explicit acknowledgement that AWS CloudFormation
@@ -208,7 +330,7 @@ class PipelineDeployStackActionProps():
         stability
         :stability: experimental
         """
-        return self._values.get('capabilities')
+        return self._values.get("capabilities")
 
     @builtins.property
     def change_set_name(self) -> typing.Optional[str]:
@@ -220,7 +342,7 @@ class PipelineDeployStackActionProps():
         stability
         :stability: experimental
         """
-        return self._values.get('change_set_name')
+        return self._values.get("change_set_name")
 
     @builtins.property
     def create_change_set_action_name(self) -> typing.Optional[str]:
@@ -232,7 +354,7 @@ class PipelineDeployStackActionProps():
         stability
         :stability: experimental
         """
-        return self._values.get('create_change_set_action_name')
+        return self._values.get("create_change_set_action_name")
 
     @builtins.property
     def create_change_set_run_order(self) -> typing.Optional[jsii.Number]:
@@ -244,7 +366,7 @@ class PipelineDeployStackActionProps():
         stability
         :stability: experimental
         """
-        return self._values.get('create_change_set_run_order')
+        return self._values.get("create_change_set_run_order")
 
     @builtins.property
     def execute_change_set_action_name(self) -> typing.Optional[str]:
@@ -256,7 +378,7 @@ class PipelineDeployStackActionProps():
         stability
         :stability: experimental
         """
-        return self._values.get('execute_change_set_action_name')
+        return self._values.get("execute_change_set_action_name")
 
     @builtins.property
     def execute_change_set_run_order(self) -> typing.Optional[jsii.Number]:
@@ -268,7 +390,7 @@ class PipelineDeployStackActionProps():
         stability
         :stability: experimental
         """
-        return self._values.get('execute_change_set_run_order')
+        return self._values.get("execute_change_set_run_order")
 
     @builtins.property
     def role(self) -> typing.Optional[_IRole_e69bbae4]:
@@ -284,7 +406,7 @@ class PipelineDeployStackActionProps():
         stability
         :stability: experimental
         """
-        return self._values.get('role')
+        return self._values.get("role")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -293,7 +415,9 @@ class PipelineDeployStackActionProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'PipelineDeployStackActionProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "PipelineDeployStackActionProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
