@@ -14,8 +14,6 @@ from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
     IResolvable as _IResolvable_9ceae33e,
-    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
-    ICfnFinder as _ICfnFinder_3b168f30,
     TreeInspector as _TreeInspector_154f5999,
     TagManager as _TagManager_2508893f,
     IInspectable as _IInspectable_051e6ed8,
@@ -52,12 +50,19 @@ class CfnBroker(
             _IResolvable_9ceae33e,
             typing.List[typing.Union["UserProperty", _IResolvable_9ceae33e]],
         ],
+        authentication_strategy: typing.Optional[str] = None,
         configuration: typing.Optional[
             typing.Union["ConfigurationIdProperty", _IResolvable_9ceae33e]
         ] = None,
         encryption_options: typing.Optional[
             typing.Union["EncryptionOptionsProperty", _IResolvable_9ceae33e]
         ] = None,
+        ldap_metadata: typing.Optional[
+            typing.Union["LdapMetadataProperty", _IResolvable_9ceae33e]
+        ] = None,
+        ldap_server_metadata: typing.Optional[
+            typing.Union["LdapServerMetadataProperty", _IResolvable_9ceae33e]
+        ] = None,
         logs: typing.Optional[
             typing.Union["LogListProperty", _IResolvable_9ceae33e]
         ] = None,
@@ -81,8 +86,11 @@ class CfnBroker(
         :param host_instance_type: ``AWS::AmazonMQ::Broker.HostInstanceType``.
         :param publicly_accessible: ``AWS::AmazonMQ::Broker.PubliclyAccessible``.
         :param users: ``AWS::AmazonMQ::Broker.Users``.
+        :param authentication_strategy: ``AWS::AmazonMQ::Broker.AuthenticationStrategy``.
         :param configuration: ``AWS::AmazonMQ::Broker.Configuration``.
         :param encryption_options: ``AWS::AmazonMQ::Broker.EncryptionOptions``.
+        :param ldap_metadata: ``AWS::AmazonMQ::Broker.LdapMetadata``.
+        :param ldap_server_metadata: ``AWS::AmazonMQ::Broker.LdapServerMetadata``.
         :param logs: ``AWS::AmazonMQ::Broker.Logs``.
         :param maintenance_window_start_time: ``AWS::AmazonMQ::Broker.MaintenanceWindowStartTime``.
         :param security_groups: ``AWS::AmazonMQ::Broker.SecurityGroups``.
@@ -99,8 +107,11 @@ class CfnBroker(
             host_instance_type=host_instance_type,
             publicly_accessible=publicly_accessible,
             users=users,
+            authentication_strategy=authentication_strategy,
             configuration=configuration,
             encryption_options=encryption_options,
+            ldap_metadata=ldap_metadata,
+            ldap_server_metadata=ldap_server_metadata,
             logs=logs,
             maintenance_window_start_time=maintenance_window_start_time,
             security_groups=security_groups,
@@ -111,34 +122,6 @@ class CfnBroker(
 
         jsii.create(CfnBroker, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnBroker":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -388,6 +371,20 @@ class CfnBroker(
     ) -> None:
         jsii.set(self, "users", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="authenticationStrategy")
+    def authentication_strategy(self) -> typing.Optional[str]:
+        """``AWS::AmazonMQ::Broker.AuthenticationStrategy``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-amazonmq-broker.html#cfn-amazonmq-broker-authenticationstrategy
+        """
+        return jsii.get(self, "authenticationStrategy")
+
+    @authentication_strategy.setter
+    def authentication_strategy(self, value: typing.Optional[str]) -> None:
+        jsii.set(self, "authenticationStrategy", value)
+
     @builtins.property
     @jsii.member(jsii_name="configuration")
     def configuration(
@@ -434,6 +431,50 @@ class CfnBroker(
     ) -> None:
         jsii.set(self, "encryptionOptions", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="ldapMetadata")
+    def ldap_metadata(
+        self,
+    ) -> typing.Optional[typing.Union["LdapMetadataProperty", _IResolvable_9ceae33e]]:
+        """``AWS::AmazonMQ::Broker.LdapMetadata``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-amazonmq-broker.html#cfn-amazonmq-broker-ldapmetadata
+        """
+        return jsii.get(self, "ldapMetadata")
+
+    @ldap_metadata.setter
+    def ldap_metadata(
+        self,
+        value: typing.Optional[
+            typing.Union["LdapMetadataProperty", _IResolvable_9ceae33e]
+        ],
+    ) -> None:
+        jsii.set(self, "ldapMetadata", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="ldapServerMetadata")
+    def ldap_server_metadata(
+        self,
+    ) -> typing.Optional[
+        typing.Union["LdapServerMetadataProperty", _IResolvable_9ceae33e]
+    ]:
+        """``AWS::AmazonMQ::Broker.LdapServerMetadata``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-amazonmq-broker.html#cfn-amazonmq-broker-ldapservermetadata
+        """
+        return jsii.get(self, "ldapServerMetadata")
+
+    @ldap_server_metadata.setter
+    def ldap_server_metadata(
+        self,
+        value: typing.Optional[
+            typing.Union["LdapServerMetadataProperty", _IResolvable_9ceae33e]
+        ],
+    ) -> None:
+        jsii.set(self, "ldapServerMetadata", value)
+
     @builtins.property
     @jsii.member(jsii_name="logs")
     def logs(
@@ -620,6 +661,320 @@ class CfnBroker(
                 k + "=" + repr(v) for k, v in self._values.items()
             )
 
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_amazonmq.CfnBroker.InterBrokerCredProperty",
+        jsii_struct_bases=[],
+        name_mapping={"password": "password", "username": "username"},
+    )
+    class InterBrokerCredProperty:
+        def __init__(self, *, password: str, username: str) -> None:
+            """
+            :param password: ``CfnBroker.InterBrokerCredProperty.Password``.
+            :param username: ``CfnBroker.InterBrokerCredProperty.Username``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-interbrokercred.html
+            """
+            self._values = {
+                "password": password,
+                "username": username,
+            }
+
+        @builtins.property
+        def password(self) -> str:
+            """``CfnBroker.InterBrokerCredProperty.Password``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-interbrokercred.html#cfn-amazonmq-broker-interbrokercred-password
+            """
+            return self._values.get("password")
+
+        @builtins.property
+        def username(self) -> str:
+            """``CfnBroker.InterBrokerCredProperty.Username``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-interbrokercred.html#cfn-amazonmq-broker-interbrokercred-username
+            """
+            return self._values.get("username")
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "InterBrokerCredProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_amazonmq.CfnBroker.LdapMetadataProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "server_metadata": "serverMetadata",
+            "inter_broker_creds": "interBrokerCreds",
+        },
+    )
+    class LdapMetadataProperty:
+        def __init__(
+            self,
+            *,
+            server_metadata: typing.Union[
+                "CfnBroker.ServerMetadataProperty", _IResolvable_9ceae33e
+            ],
+            inter_broker_creds: typing.Optional[
+                typing.Union[
+                    _IResolvable_9ceae33e,
+                    typing.List[
+                        typing.Union[
+                            "CfnBroker.InterBrokerCredProperty", _IResolvable_9ceae33e
+                        ]
+                    ],
+                ]
+            ] = None,
+        ) -> None:
+            """
+            :param server_metadata: ``CfnBroker.LdapMetadataProperty.ServerMetadata``.
+            :param inter_broker_creds: ``CfnBroker.LdapMetadataProperty.InterBrokerCreds``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapmetadata.html
+            """
+            self._values = {
+                "server_metadata": server_metadata,
+            }
+            if inter_broker_creds is not None:
+                self._values["inter_broker_creds"] = inter_broker_creds
+
+        @builtins.property
+        def server_metadata(
+            self,
+        ) -> typing.Union["CfnBroker.ServerMetadataProperty", _IResolvable_9ceae33e]:
+            """``CfnBroker.LdapMetadataProperty.ServerMetadata``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapmetadata.html#cfn-amazonmq-broker-ldapmetadata-servermetadata
+            """
+            return self._values.get("server_metadata")
+
+        @builtins.property
+        def inter_broker_creds(
+            self,
+        ) -> typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union[
+                        "CfnBroker.InterBrokerCredProperty", _IResolvable_9ceae33e
+                    ]
+                ],
+            ]
+        ]:
+            """``CfnBroker.LdapMetadataProperty.InterBrokerCreds``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapmetadata.html#cfn-amazonmq-broker-ldapmetadata-interbrokercreds
+            """
+            return self._values.get("inter_broker_creds")
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "LdapMetadataProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_amazonmq.CfnBroker.LdapServerMetadataProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "hosts": "hosts",
+            "role_base": "roleBase",
+            "role_search_matching": "roleSearchMatching",
+            "service_account_password": "serviceAccountPassword",
+            "service_account_username": "serviceAccountUsername",
+            "user_base": "userBase",
+            "user_search_matching": "userSearchMatching",
+            "role_name": "roleName",
+            "role_search_subtree": "roleSearchSubtree",
+            "user_role_name": "userRoleName",
+            "user_search_subtree": "userSearchSubtree",
+        },
+    )
+    class LdapServerMetadataProperty:
+        def __init__(
+            self,
+            *,
+            hosts: typing.List[str],
+            role_base: str,
+            role_search_matching: str,
+            service_account_password: str,
+            service_account_username: str,
+            user_base: str,
+            user_search_matching: str,
+            role_name: typing.Optional[str] = None,
+            role_search_subtree: typing.Optional[
+                typing.Union[bool, _IResolvable_9ceae33e]
+            ] = None,
+            user_role_name: typing.Optional[str] = None,
+            user_search_subtree: typing.Optional[
+                typing.Union[bool, _IResolvable_9ceae33e]
+            ] = None,
+        ) -> None:
+            """
+            :param hosts: ``CfnBroker.LdapServerMetadataProperty.Hosts``.
+            :param role_base: ``CfnBroker.LdapServerMetadataProperty.RoleBase``.
+            :param role_search_matching: ``CfnBroker.LdapServerMetadataProperty.RoleSearchMatching``.
+            :param service_account_password: ``CfnBroker.LdapServerMetadataProperty.ServiceAccountPassword``.
+            :param service_account_username: ``CfnBroker.LdapServerMetadataProperty.ServiceAccountUsername``.
+            :param user_base: ``CfnBroker.LdapServerMetadataProperty.UserBase``.
+            :param user_search_matching: ``CfnBroker.LdapServerMetadataProperty.UserSearchMatching``.
+            :param role_name: ``CfnBroker.LdapServerMetadataProperty.RoleName``.
+            :param role_search_subtree: ``CfnBroker.LdapServerMetadataProperty.RoleSearchSubtree``.
+            :param user_role_name: ``CfnBroker.LdapServerMetadataProperty.UserRoleName``.
+            :param user_search_subtree: ``CfnBroker.LdapServerMetadataProperty.UserSearchSubtree``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html
+            """
+            self._values = {
+                "hosts": hosts,
+                "role_base": role_base,
+                "role_search_matching": role_search_matching,
+                "service_account_password": service_account_password,
+                "service_account_username": service_account_username,
+                "user_base": user_base,
+                "user_search_matching": user_search_matching,
+            }
+            if role_name is not None:
+                self._values["role_name"] = role_name
+            if role_search_subtree is not None:
+                self._values["role_search_subtree"] = role_search_subtree
+            if user_role_name is not None:
+                self._values["user_role_name"] = user_role_name
+            if user_search_subtree is not None:
+                self._values["user_search_subtree"] = user_search_subtree
+
+        @builtins.property
+        def hosts(self) -> typing.List[str]:
+            """``CfnBroker.LdapServerMetadataProperty.Hosts``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html#cfn-amazonmq-broker-ldapservermetadata-hosts
+            """
+            return self._values.get("hosts")
+
+        @builtins.property
+        def role_base(self) -> str:
+            """``CfnBroker.LdapServerMetadataProperty.RoleBase``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html#cfn-amazonmq-broker-ldapservermetadata-rolebase
+            """
+            return self._values.get("role_base")
+
+        @builtins.property
+        def role_search_matching(self) -> str:
+            """``CfnBroker.LdapServerMetadataProperty.RoleSearchMatching``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html#cfn-amazonmq-broker-ldapservermetadata-rolesearchmatching
+            """
+            return self._values.get("role_search_matching")
+
+        @builtins.property
+        def service_account_password(self) -> str:
+            """``CfnBroker.LdapServerMetadataProperty.ServiceAccountPassword``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html#cfn-amazonmq-broker-ldapservermetadata-serviceaccountpassword
+            """
+            return self._values.get("service_account_password")
+
+        @builtins.property
+        def service_account_username(self) -> str:
+            """``CfnBroker.LdapServerMetadataProperty.ServiceAccountUsername``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html#cfn-amazonmq-broker-ldapservermetadata-serviceaccountusername
+            """
+            return self._values.get("service_account_username")
+
+        @builtins.property
+        def user_base(self) -> str:
+            """``CfnBroker.LdapServerMetadataProperty.UserBase``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html#cfn-amazonmq-broker-ldapservermetadata-userbase
+            """
+            return self._values.get("user_base")
+
+        @builtins.property
+        def user_search_matching(self) -> str:
+            """``CfnBroker.LdapServerMetadataProperty.UserSearchMatching``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html#cfn-amazonmq-broker-ldapservermetadata-usersearchmatching
+            """
+            return self._values.get("user_search_matching")
+
+        @builtins.property
+        def role_name(self) -> typing.Optional[str]:
+            """``CfnBroker.LdapServerMetadataProperty.RoleName``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html#cfn-amazonmq-broker-ldapservermetadata-rolename
+            """
+            return self._values.get("role_name")
+
+        @builtins.property
+        def role_search_subtree(
+            self,
+        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+            """``CfnBroker.LdapServerMetadataProperty.RoleSearchSubtree``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html#cfn-amazonmq-broker-ldapservermetadata-rolesearchsubtree
+            """
+            return self._values.get("role_search_subtree")
+
+        @builtins.property
+        def user_role_name(self) -> typing.Optional[str]:
+            """``CfnBroker.LdapServerMetadataProperty.UserRoleName``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html#cfn-amazonmq-broker-ldapservermetadata-userrolename
+            """
+            return self._values.get("user_role_name")
+
+        @builtins.property
+        def user_search_subtree(
+            self,
+        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+            """``CfnBroker.LdapServerMetadataProperty.UserSearchSubtree``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-ldapservermetadata.html#cfn-amazonmq-broker-ldapservermetadata-usersearchsubtree
+            """
+            return self._values.get("user_search_subtree")
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "LdapServerMetadataProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_amazonmq.CfnBroker.LogListProperty",
         jsii_struct_bases=[],
@@ -739,6 +1094,191 @@ class CfnBroker(
                 k + "=" + repr(v) for k, v in self._values.items()
             )
 
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_amazonmq.CfnBroker.ServerMetadataProperty",
+        jsii_struct_bases=[],
+        name_mapping={
+            "hosts": "hosts",
+            "role_base": "roleBase",
+            "role_search_matching": "roleSearchMatching",
+            "service_account_password": "serviceAccountPassword",
+            "service_account_username": "serviceAccountUsername",
+            "user_base": "userBase",
+            "user_search_matching": "userSearchMatching",
+            "role_name": "roleName",
+            "role_search_subtree": "roleSearchSubtree",
+            "user_role_name": "userRoleName",
+            "user_search_subtree": "userSearchSubtree",
+        },
+    )
+    class ServerMetadataProperty:
+        def __init__(
+            self,
+            *,
+            hosts: typing.List[str],
+            role_base: str,
+            role_search_matching: str,
+            service_account_password: str,
+            service_account_username: str,
+            user_base: str,
+            user_search_matching: str,
+            role_name: typing.Optional[str] = None,
+            role_search_subtree: typing.Optional[
+                typing.Union[bool, _IResolvable_9ceae33e]
+            ] = None,
+            user_role_name: typing.Optional[str] = None,
+            user_search_subtree: typing.Optional[
+                typing.Union[bool, _IResolvable_9ceae33e]
+            ] = None,
+        ) -> None:
+            """
+            :param hosts: ``CfnBroker.ServerMetadataProperty.Hosts``.
+            :param role_base: ``CfnBroker.ServerMetadataProperty.RoleBase``.
+            :param role_search_matching: ``CfnBroker.ServerMetadataProperty.RoleSearchMatching``.
+            :param service_account_password: ``CfnBroker.ServerMetadataProperty.ServiceAccountPassword``.
+            :param service_account_username: ``CfnBroker.ServerMetadataProperty.ServiceAccountUsername``.
+            :param user_base: ``CfnBroker.ServerMetadataProperty.UserBase``.
+            :param user_search_matching: ``CfnBroker.ServerMetadataProperty.UserSearchMatching``.
+            :param role_name: ``CfnBroker.ServerMetadataProperty.RoleName``.
+            :param role_search_subtree: ``CfnBroker.ServerMetadataProperty.RoleSearchSubtree``.
+            :param user_role_name: ``CfnBroker.ServerMetadataProperty.UserRoleName``.
+            :param user_search_subtree: ``CfnBroker.ServerMetadataProperty.UserSearchSubtree``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-servermetadata.html
+            """
+            self._values = {
+                "hosts": hosts,
+                "role_base": role_base,
+                "role_search_matching": role_search_matching,
+                "service_account_password": service_account_password,
+                "service_account_username": service_account_username,
+                "user_base": user_base,
+                "user_search_matching": user_search_matching,
+            }
+            if role_name is not None:
+                self._values["role_name"] = role_name
+            if role_search_subtree is not None:
+                self._values["role_search_subtree"] = role_search_subtree
+            if user_role_name is not None:
+                self._values["user_role_name"] = user_role_name
+            if user_search_subtree is not None:
+                self._values["user_search_subtree"] = user_search_subtree
+
+        @builtins.property
+        def hosts(self) -> typing.List[str]:
+            """``CfnBroker.ServerMetadataProperty.Hosts``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-servermetadata.html#cfn-amazonmq-broker-servermetadata-hosts
+            """
+            return self._values.get("hosts")
+
+        @builtins.property
+        def role_base(self) -> str:
+            """``CfnBroker.ServerMetadataProperty.RoleBase``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-servermetadata.html#cfn-amazonmq-broker-servermetadata-rolebase
+            """
+            return self._values.get("role_base")
+
+        @builtins.property
+        def role_search_matching(self) -> str:
+            """``CfnBroker.ServerMetadataProperty.RoleSearchMatching``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-servermetadata.html#cfn-amazonmq-broker-servermetadata-rolesearchmatching
+            """
+            return self._values.get("role_search_matching")
+
+        @builtins.property
+        def service_account_password(self) -> str:
+            """``CfnBroker.ServerMetadataProperty.ServiceAccountPassword``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-servermetadata.html#cfn-amazonmq-broker-servermetadata-serviceaccountpassword
+            """
+            return self._values.get("service_account_password")
+
+        @builtins.property
+        def service_account_username(self) -> str:
+            """``CfnBroker.ServerMetadataProperty.ServiceAccountUsername``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-servermetadata.html#cfn-amazonmq-broker-servermetadata-serviceaccountusername
+            """
+            return self._values.get("service_account_username")
+
+        @builtins.property
+        def user_base(self) -> str:
+            """``CfnBroker.ServerMetadataProperty.UserBase``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-servermetadata.html#cfn-amazonmq-broker-servermetadata-userbase
+            """
+            return self._values.get("user_base")
+
+        @builtins.property
+        def user_search_matching(self) -> str:
+            """``CfnBroker.ServerMetadataProperty.UserSearchMatching``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-servermetadata.html#cfn-amazonmq-broker-servermetadata-usersearchmatching
+            """
+            return self._values.get("user_search_matching")
+
+        @builtins.property
+        def role_name(self) -> typing.Optional[str]:
+            """``CfnBroker.ServerMetadataProperty.RoleName``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-servermetadata.html#cfn-amazonmq-broker-servermetadata-rolename
+            """
+            return self._values.get("role_name")
+
+        @builtins.property
+        def role_search_subtree(
+            self,
+        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+            """``CfnBroker.ServerMetadataProperty.RoleSearchSubtree``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-servermetadata.html#cfn-amazonmq-broker-servermetadata-rolesearchsubtree
+            """
+            return self._values.get("role_search_subtree")
+
+        @builtins.property
+        def user_role_name(self) -> typing.Optional[str]:
+            """``CfnBroker.ServerMetadataProperty.UserRoleName``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-servermetadata.html#cfn-amazonmq-broker-servermetadata-userrolename
+            """
+            return self._values.get("user_role_name")
+
+        @builtins.property
+        def user_search_subtree(
+            self,
+        ) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
+            """``CfnBroker.ServerMetadataProperty.UserSearchSubtree``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-amazonmq-broker-servermetadata.html#cfn-amazonmq-broker-servermetadata-usersearchsubtree
+            """
+            return self._values.get("user_search_subtree")
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "ServerMetadataProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_amazonmq.CfnBroker.TagsEntryProperty",
         jsii_struct_bases=[],
@@ -888,8 +1428,11 @@ class CfnBroker(
         "host_instance_type": "hostInstanceType",
         "publicly_accessible": "publiclyAccessible",
         "users": "users",
+        "authentication_strategy": "authenticationStrategy",
         "configuration": "configuration",
         "encryption_options": "encryptionOptions",
+        "ldap_metadata": "ldapMetadata",
+        "ldap_server_metadata": "ldapServerMetadata",
         "logs": "logs",
         "maintenance_window_start_time": "maintenanceWindowStartTime",
         "security_groups": "securityGroups",
@@ -913,12 +1456,19 @@ class CfnBrokerProps:
             _IResolvable_9ceae33e,
             typing.List[typing.Union["CfnBroker.UserProperty", _IResolvable_9ceae33e]],
         ],
+        authentication_strategy: typing.Optional[str] = None,
         configuration: typing.Optional[
             typing.Union["CfnBroker.ConfigurationIdProperty", _IResolvable_9ceae33e]
         ] = None,
         encryption_options: typing.Optional[
             typing.Union["CfnBroker.EncryptionOptionsProperty", _IResolvable_9ceae33e]
         ] = None,
+        ldap_metadata: typing.Optional[
+            typing.Union["CfnBroker.LdapMetadataProperty", _IResolvable_9ceae33e]
+        ] = None,
+        ldap_server_metadata: typing.Optional[
+            typing.Union["CfnBroker.LdapServerMetadataProperty", _IResolvable_9ceae33e]
+        ] = None,
         logs: typing.Optional[
             typing.Union["CfnBroker.LogListProperty", _IResolvable_9ceae33e]
         ] = None,
@@ -940,8 +1490,11 @@ class CfnBrokerProps:
         :param host_instance_type: ``AWS::AmazonMQ::Broker.HostInstanceType``.
         :param publicly_accessible: ``AWS::AmazonMQ::Broker.PubliclyAccessible``.
         :param users: ``AWS::AmazonMQ::Broker.Users``.
+        :param authentication_strategy: ``AWS::AmazonMQ::Broker.AuthenticationStrategy``.
         :param configuration: ``AWS::AmazonMQ::Broker.Configuration``.
         :param encryption_options: ``AWS::AmazonMQ::Broker.EncryptionOptions``.
+        :param ldap_metadata: ``AWS::AmazonMQ::Broker.LdapMetadata``.
+        :param ldap_server_metadata: ``AWS::AmazonMQ::Broker.LdapServerMetadata``.
         :param logs: ``AWS::AmazonMQ::Broker.Logs``.
         :param maintenance_window_start_time: ``AWS::AmazonMQ::Broker.MaintenanceWindowStartTime``.
         :param security_groups: ``AWS::AmazonMQ::Broker.SecurityGroups``.
@@ -962,10 +1515,16 @@ class CfnBrokerProps:
             "publicly_accessible": publicly_accessible,
             "users": users,
         }
+        if authentication_strategy is not None:
+            self._values["authentication_strategy"] = authentication_strategy
         if configuration is not None:
             self._values["configuration"] = configuration
         if encryption_options is not None:
             self._values["encryption_options"] = encryption_options
+        if ldap_metadata is not None:
+            self._values["ldap_metadata"] = ldap_metadata
+        if ldap_server_metadata is not None:
+            self._values["ldap_server_metadata"] = ldap_server_metadata
         if logs is not None:
             self._values["logs"] = logs
         if maintenance_window_start_time is not None:
@@ -1058,6 +1617,15 @@ class CfnBrokerProps:
         """
         return self._values.get("users")
 
+    @builtins.property
+    def authentication_strategy(self) -> typing.Optional[str]:
+        """``AWS::AmazonMQ::Broker.AuthenticationStrategy``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-amazonmq-broker.html#cfn-amazonmq-broker-authenticationstrategy
+        """
+        return self._values.get("authentication_strategy")
+
     @builtins.property
     def configuration(
         self,
@@ -1084,6 +1652,32 @@ class CfnBrokerProps:
         """
         return self._values.get("encryption_options")
 
+    @builtins.property
+    def ldap_metadata(
+        self,
+    ) -> typing.Optional[
+        typing.Union["CfnBroker.LdapMetadataProperty", _IResolvable_9ceae33e]
+    ]:
+        """``AWS::AmazonMQ::Broker.LdapMetadata``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-amazonmq-broker.html#cfn-amazonmq-broker-ldapmetadata
+        """
+        return self._values.get("ldap_metadata")
+
+    @builtins.property
+    def ldap_server_metadata(
+        self,
+    ) -> typing.Optional[
+        typing.Union["CfnBroker.LdapServerMetadataProperty", _IResolvable_9ceae33e]
+    ]:
+        """``AWS::AmazonMQ::Broker.LdapServerMetadata``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-amazonmq-broker.html#cfn-amazonmq-broker-ldapservermetadata
+        """
+        return self._values.get("ldap_server_metadata")
+
     @builtins.property
     def logs(
         self,
@@ -1206,34 +1800,6 @@ class CfnConfiguration(
 
         jsii.create(CfnConfiguration, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnConfiguration":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -1456,34 +2022,6 @@ class CfnConfigurationAssociation(
 
         jsii.create(CfnConfigurationAssociation, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnConfigurationAssociation":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
