@@ -13,9 +13,10 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
-    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
-    ICfnFinder as _ICfnFinder_3b168f30,
+    IResolvable as _IResolvable_9ceae33e,
+    CfnTag as _CfnTag_b4661f1a,
     TreeInspector as _TreeInspector_154f5999,
+    TagManager as _TagManager_2508893f,
     IInspectable as _IInspectable_051e6ed8,
     IResource as _IResource_72f7ee7e,
     Resource as _Resource_884d0774,
@@ -44,7 +45,14 @@ class CfnProfilingGroup(
         *,
         profiling_group_name: str,
         agent_permissions: typing.Any = None,
+        anomaly_detection_notification_configuration: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]],
+            ]
+        ] = None,
         compute_platform: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::CodeGuruProfiler::ProfilingGroup``.
 
@@ -52,44 +60,20 @@ class CfnProfilingGroup(
         :param id: - scoped id of the resource.
         :param profiling_group_name: ``AWS::CodeGuruProfiler::ProfilingGroup.ProfilingGroupName``.
         :param agent_permissions: ``AWS::CodeGuruProfiler::ProfilingGroup.AgentPermissions``.
+        :param anomaly_detection_notification_configuration: ``AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration``.
         :param compute_platform: ``AWS::CodeGuruProfiler::ProfilingGroup.ComputePlatform``.
+        :param tags: ``AWS::CodeGuruProfiler::ProfilingGroup.Tags``.
         """
         props = CfnProfilingGroupProps(
             profiling_group_name=profiling_group_name,
             agent_permissions=agent_permissions,
+            anomaly_detection_notification_configuration=anomaly_detection_notification_configuration,
             compute_platform=compute_platform,
+            tags=tags,
         )
 
         jsii.create(CfnProfilingGroup, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnProfilingGroup":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -130,6 +114,16 @@ class CfnProfilingGroup(
     def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
+    @builtins.property
+    @jsii.member(jsii_name="tags")
+    def tags(self) -> _TagManager_2508893f:
+        """``AWS::CodeGuruProfiler::ProfilingGroup.Tags``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-tags
+        """
+        return jsii.get(self, "tags")
+
     @builtins.property
     @jsii.member(jsii_name="agentPermissions")
     def agent_permissions(self) -> typing.Any:
@@ -158,6 +152,35 @@ class CfnProfilingGroup(
     def profiling_group_name(self, value: str) -> None:
         jsii.set(self, "profilingGroupName", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="anomalyDetectionNotificationConfiguration")
+    def anomaly_detection_notification_configuration(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]],
+        ]
+    ]:
+        """``AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-anomalydetectionnotificationconfiguration
+        """
+        return jsii.get(self, "anomalyDetectionNotificationConfiguration")
+
+    @anomaly_detection_notification_configuration.setter
+    def anomaly_detection_notification_configuration(
+        self,
+        value: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[typing.Union["ChannelProperty", _IResolvable_9ceae33e]],
+            ]
+        ],
+    ) -> None:
+        jsii.set(self, "anomalyDetectionNotificationConfiguration", value)
+
     @builtins.property
     @jsii.member(jsii_name="computePlatform")
     def compute_platform(self) -> typing.Optional[str]:
@@ -172,6 +195,57 @@ class CfnProfilingGroup(
     def compute_platform(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "computePlatform", value)
 
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_codeguruprofiler.CfnProfilingGroup.ChannelProperty",
+        jsii_struct_bases=[],
+        name_mapping={"channel_uri": "channelUri", "channel_id": "channelId"},
+    )
+    class ChannelProperty:
+        def __init__(
+            self, *, channel_uri: str, channel_id: typing.Optional[str] = None
+        ) -> None:
+            """
+            :param channel_uri: ``CfnProfilingGroup.ChannelProperty.channelUri``.
+            :param channel_id: ``CfnProfilingGroup.ChannelProperty.channelId``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-channel.html
+            """
+            self._values = {
+                "channel_uri": channel_uri,
+            }
+            if channel_id is not None:
+                self._values["channel_id"] = channel_id
+
+        @builtins.property
+        def channel_uri(self) -> str:
+            """``CfnProfilingGroup.ChannelProperty.channelUri``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-channel.html#cfn-codeguruprofiler-profilinggroup-channel-channeluri
+            """
+            return self._values.get("channel_uri")
+
+        @builtins.property
+        def channel_id(self) -> typing.Optional[str]:
+            """``CfnProfilingGroup.ChannelProperty.channelId``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codeguruprofiler-profilinggroup-channel.html#cfn-codeguruprofiler-profilinggroup-channel-channelid
+            """
+            return self._values.get("channel_id")
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "ChannelProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
 
 @jsii.data_type(
     jsii_type="monocdk-experiment.aws_codeguruprofiler.CfnProfilingGroupProps",
@@ -179,7 +253,9 @@ class CfnProfilingGroup(
     name_mapping={
         "profiling_group_name": "profilingGroupName",
         "agent_permissions": "agentPermissions",
+        "anomaly_detection_notification_configuration": "anomalyDetectionNotificationConfiguration",
         "compute_platform": "computePlatform",
+        "tags": "tags",
     },
 )
 class CfnProfilingGroupProps:
@@ -188,13 +264,26 @@ class CfnProfilingGroupProps:
         *,
         profiling_group_name: str,
         agent_permissions: typing.Any = None,
+        anomaly_detection_notification_configuration: typing.Optional[
+            typing.Union[
+                _IResolvable_9ceae33e,
+                typing.List[
+                    typing.Union[
+                        "CfnProfilingGroup.ChannelProperty", _IResolvable_9ceae33e
+                    ]
+                ],
+            ]
+        ] = None,
         compute_platform: typing.Optional[str] = None,
+        tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::CodeGuruProfiler::ProfilingGroup``.
 
         :param profiling_group_name: ``AWS::CodeGuruProfiler::ProfilingGroup.ProfilingGroupName``.
         :param agent_permissions: ``AWS::CodeGuruProfiler::ProfilingGroup.AgentPermissions``.
+        :param anomaly_detection_notification_configuration: ``AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration``.
         :param compute_platform: ``AWS::CodeGuruProfiler::ProfilingGroup.ComputePlatform``.
+        :param tags: ``AWS::CodeGuruProfiler::ProfilingGroup.Tags``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html
@@ -204,8 +293,14 @@ class CfnProfilingGroupProps:
         }
         if agent_permissions is not None:
             self._values["agent_permissions"] = agent_permissions
+        if anomaly_detection_notification_configuration is not None:
+            self._values[
+                "anomaly_detection_notification_configuration"
+            ] = anomaly_detection_notification_configuration
         if compute_platform is not None:
             self._values["compute_platform"] = compute_platform
+        if tags is not None:
+            self._values["tags"] = tags
 
     @builtins.property
     def profiling_group_name(self) -> str:
@@ -225,6 +320,24 @@ class CfnProfilingGroupProps:
         """
         return self._values.get("agent_permissions")
 
+    @builtins.property
+    def anomaly_detection_notification_configuration(
+        self,
+    ) -> typing.Optional[
+        typing.Union[
+            _IResolvable_9ceae33e,
+            typing.List[
+                typing.Union["CfnProfilingGroup.ChannelProperty", _IResolvable_9ceae33e]
+            ],
+        ]
+    ]:
+        """``AWS::CodeGuruProfiler::ProfilingGroup.AnomalyDetectionNotificationConfiguration``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-anomalydetectionnotificationconfiguration
+        """
+        return self._values.get("anomaly_detection_notification_configuration")
+
     @builtins.property
     def compute_platform(self) -> typing.Optional[str]:
         """``AWS::CodeGuruProfiler::ProfilingGroup.ComputePlatform``.
@@ -234,6 +347,15 @@ class CfnProfilingGroupProps:
         """
         return self._values.get("compute_platform")
 
+    @builtins.property
+    def tags(self) -> typing.Optional[typing.List[_CfnTag_b4661f1a]]:
+        """``AWS::CodeGuruProfiler::ProfilingGroup.Tags``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codeguruprofiler-profilinggroup.html#cfn-codeguruprofiler-profilinggroup-tags
+        """
+        return self._values.get("tags")
+
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -246,6 +368,28 @@ class CfnProfilingGroupProps:
         )
 
 
+@jsii.enum(jsii_type="monocdk-experiment.aws_codeguruprofiler.ComputePlatform")
+class ComputePlatform(enum.Enum):
+    """The compute platform of the profiling group.
+
+    stability
+    :stability: experimental
+    """
+
+    AWS_LAMBDA = "AWS_LAMBDA"
+    """Use AWS_LAMBDA if your application runs on AWS Lambda.
+
+    stability
+    :stability: experimental
+    """
+    DEFAULT = "DEFAULT"
+    """Use Default if your application runs on a compute platform that is not AWS Lambda, such an Amazon EC2 instance, an on-premises server, or a different platform.
+
+    stability
+    :stability: experimental
+    """
+
+
 @jsii.interface(jsii_type="monocdk-experiment.aws_codeguruprofiler.IProfilingGroup")
 class IProfilingGroup(_IResource_72f7ee7e, jsii.compat.Protocol):
     """IResource represents a Profiling Group.
@@ -374,17 +518,21 @@ class ProfilingGroup(
         scope: _Construct_f50a3f53,
         id: str,
         *,
+        compute_platform: typing.Optional["ComputePlatform"] = None,
         profiling_group_name: typing.Optional[str] = None,
     ) -> None:
         """
         :param scope: -
         :param id: -
+        :param compute_platform: The compute platform of the profiling group. Default: ComputePlatform.DEFAULT
         :param profiling_group_name: A name for the profiling group. Default: - automatically generated name.
 
         stability
         :stability: experimental
         """
-        props = ProfilingGroupProps(profiling_group_name=profiling_group_name)
+        props = ProfilingGroupProps(
+            compute_platform=compute_platform, profiling_group_name=profiling_group_name
+        )
 
         jsii.create(ProfilingGroup, self, [scope, id, props])
 
@@ -484,21 +632,44 @@ class ProfilingGroup(
 @jsii.data_type(
     jsii_type="monocdk-experiment.aws_codeguruprofiler.ProfilingGroupProps",
     jsii_struct_bases=[],
-    name_mapping={"profiling_group_name": "profilingGroupName"},
+    name_mapping={
+        "compute_platform": "computePlatform",
+        "profiling_group_name": "profilingGroupName",
+    },
 )
 class ProfilingGroupProps:
-    def __init__(self, *, profiling_group_name: typing.Optional[str] = None) -> None:
+    def __init__(
+        self,
+        *,
+        compute_platform: typing.Optional["ComputePlatform"] = None,
+        profiling_group_name: typing.Optional[str] = None,
+    ) -> None:
         """Properties for creating a new Profiling Group.
 
+        :param compute_platform: The compute platform of the profiling group. Default: ComputePlatform.DEFAULT
         :param profiling_group_name: A name for the profiling group. Default: - automatically generated name.
 
         stability
         :stability: experimental
         """
         self._values = {}
+        if compute_platform is not None:
+            self._values["compute_platform"] = compute_platform
         if profiling_group_name is not None:
             self._values["profiling_group_name"] = profiling_group_name
 
+    @builtins.property
+    def compute_platform(self) -> typing.Optional["ComputePlatform"]:
+        """The compute platform of the profiling group.
+
+        default
+        :default: ComputePlatform.DEFAULT
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("compute_platform")
+
     @builtins.property
     def profiling_group_name(self) -> typing.Optional[str]:
         """A name for the profiling group.
@@ -526,6 +697,7 @@ class ProfilingGroupProps:
 __all__ = [
     "CfnProfilingGroup",
     "CfnProfilingGroupProps",
+    "ComputePlatform",
     "IProfilingGroup",
     "ProfilingGroup",
     "ProfilingGroupProps",
