@@ -14,8 +14,6 @@ from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
     CfnTag as _CfnTag_b4661f1a,
-    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
-    ICfnFinder as _ICfnFinder_3b168f30,
     TreeInspector as _TreeInspector_154f5999,
     TagManager as _TagManager_2508893f,
     IInspectable as _IInspectable_051e6ed8,
@@ -42,7 +40,8 @@ class CfnConnection(
         id: str,
         *,
         connection_name: str,
-        provider_type: str,
+        host_arn: typing.Optional[str] = None,
+        provider_type: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Create a new ``AWS::CodeStarConnections::Connection``.
@@ -50,43 +49,19 @@ class CfnConnection(
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
         :param connection_name: ``AWS::CodeStarConnections::Connection.ConnectionName``.
+        :param host_arn: ``AWS::CodeStarConnections::Connection.HostArn``.
         :param provider_type: ``AWS::CodeStarConnections::Connection.ProviderType``.
         :param tags: ``AWS::CodeStarConnections::Connection.Tags``.
         """
         props = CfnConnectionProps(
-            connection_name=connection_name, provider_type=provider_type, tags=tags
+            connection_name=connection_name,
+            host_arn=host_arn,
+            provider_type=provider_type,
+            tags=tags,
         )
 
         jsii.create(CfnConnection, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnConnection":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -169,9 +144,23 @@ class CfnConnection(
     def connection_name(self, value: str) -> None:
         jsii.set(self, "connectionName", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="hostArn")
+    def host_arn(self) -> typing.Optional[str]:
+        """``AWS::CodeStarConnections::Connection.HostArn``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarconnections-connection.html#cfn-codestarconnections-connection-hostarn
+        """
+        return jsii.get(self, "hostArn")
+
+    @host_arn.setter
+    def host_arn(self, value: typing.Optional[str]) -> None:
+        jsii.set(self, "hostArn", value)
+
     @builtins.property
     @jsii.member(jsii_name="providerType")
-    def provider_type(self) -> str:
+    def provider_type(self) -> typing.Optional[str]:
         """``AWS::CodeStarConnections::Connection.ProviderType``.
 
         see
@@ -180,7 +169,7 @@ class CfnConnection(
         return jsii.get(self, "providerType")
 
     @provider_type.setter
-    def provider_type(self, value: str) -> None:
+    def provider_type(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "providerType", value)
 
 
@@ -189,6 +178,7 @@ class CfnConnection(
     jsii_struct_bases=[],
     name_mapping={
         "connection_name": "connectionName",
+        "host_arn": "hostArn",
         "provider_type": "providerType",
         "tags": "tags",
     },
@@ -198,12 +188,14 @@ class CfnConnectionProps:
         self,
         *,
         connection_name: str,
-        provider_type: str,
+        host_arn: typing.Optional[str] = None,
+        provider_type: typing.Optional[str] = None,
         tags: typing.Optional[typing.List[_CfnTag_b4661f1a]] = None,
     ) -> None:
         """Properties for defining a ``AWS::CodeStarConnections::Connection``.
 
         :param connection_name: ``AWS::CodeStarConnections::Connection.ConnectionName``.
+        :param host_arn: ``AWS::CodeStarConnections::Connection.HostArn``.
         :param provider_type: ``AWS::CodeStarConnections::Connection.ProviderType``.
         :param tags: ``AWS::CodeStarConnections::Connection.Tags``.
 
@@ -212,8 +204,11 @@ class CfnConnectionProps:
         """
         self._values = {
             "connection_name": connection_name,
-            "provider_type": provider_type,
         }
+        if host_arn is not None:
+            self._values["host_arn"] = host_arn
+        if provider_type is not None:
+            self._values["provider_type"] = provider_type
         if tags is not None:
             self._values["tags"] = tags
 
@@ -227,7 +222,16 @@ class CfnConnectionProps:
         return self._values.get("connection_name")
 
     @builtins.property
-    def provider_type(self) -> str:
+    def host_arn(self) -> typing.Optional[str]:
+        """``AWS::CodeStarConnections::Connection.HostArn``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarconnections-connection.html#cfn-codestarconnections-connection-hostarn
+        """
+        return self._values.get("host_arn")
+
+    @builtins.property
+    def provider_type(self) -> typing.Optional[str]:
         """``AWS::CodeStarConnections::Connection.ProviderType``.
 
         see
