@@ -15,8 +15,6 @@ from .. import (
     Construct as _Construct_f50a3f53,
     IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
-    ICfnFinder as _ICfnFinder_3b168f30,
     TreeInspector as _TreeInspector_154f5999,
     TagManager as _TagManager_2508893f,
     IInspectable as _IInspectable_051e6ed8,
@@ -85,34 +83,6 @@ class CfnRepository(
 
         jsii.create(CfnRepository, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnRepository":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -1289,17 +1259,23 @@ class RepositoryBase(
         scope: _Construct_f50a3f53,
         id: str,
         *,
+        account: typing.Optional[str] = None,
         physical_name: typing.Optional[str] = None,
+        region: typing.Optional[str] = None,
     ) -> None:
         """
         :param scope: -
         :param id: -
+        :param account: The AWS account ID this resource belongs to. Default: - the resource is in the same account as the stack it belongs to
         :param physical_name: The value passed in by users to the physical name prop of the resource. - ``undefined`` implies that a physical name will be allocated by CloudFormation during deployment. - a concrete value implies a specific physical name - ``PhysicalName.GENERATE_IF_NEEDED`` is a marker that indicates that a physical will only be generated by the CDK if it is needed for cross-environment references. Otherwise, it will be allocated by CloudFormation. Default: - The physical name will be allocated by CloudFormation at deployment time
+        :param region: The AWS region this resource belongs to. Default: - the resource is in the same region as the stack it belongs to
 
         stability
         :stability: experimental
         """
-        props = _ResourceProps_92be6f66(physical_name=physical_name)
+        props = _ResourceProps_92be6f66(
+            account=account, physical_name=physical_name, region=region
+        )
 
         jsii.create(RepositoryBase, self, [scope, id, props])
 
@@ -1761,17 +1737,23 @@ class Repository(
     @jsii.member(jsii_name="arnForLocalRepository")
     @builtins.classmethod
     def arn_for_local_repository(
-        cls, repository_name: str, scope: _IConstruct_db0cc7e3
+        cls,
+        repository_name: str,
+        scope: _IConstruct_db0cc7e3,
+        account: typing.Optional[str] = None,
     ) -> str:
         """Returns an ECR ARN for a repository that resides in the same account/region as the current stack.
 
         :param repository_name: -
         :param scope: -
+        :param account: -
 
         stability
         :stability: experimental
         """
-        return jsii.sinvoke(cls, "arnForLocalRepository", [repository_name, scope])
+        return jsii.sinvoke(
+            cls, "arnForLocalRepository", [repository_name, scope, account]
+        )
 
     @jsii.member(jsii_name="fromRepositoryArn")
     @builtins.classmethod
