@@ -15,8 +15,6 @@ from .. import (
     Construct as _Construct_f50a3f53,
     CfnResource as _CfnResource_7760e8e4,
     IResolvable as _IResolvable_9ceae33e,
-    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
-    ICfnFinder as _ICfnFinder_3b168f30,
     TreeInspector as _TreeInspector_154f5999,
     IInspectable as _IInspectable_051e6ed8,
     TagManager as _TagManager_2508893f,
@@ -356,34 +354,6 @@ class CfnAccessPoint(
 
         jsii.create(CfnAccessPoint, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnAccessPoint":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -932,6 +902,9 @@ class CfnFileSystem(
         scope: _Construct_f50a3f53,
         id: str,
         *,
+        backup_policy: typing.Optional[
+            typing.Union["BackupPolicyProperty", _IResolvable_9ceae33e]
+        ] = None,
         encrypted: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         file_system_policy: typing.Any = None,
         file_system_tags: typing.Optional[
@@ -954,6 +927,7 @@ class CfnFileSystem(
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
+        :param backup_policy: ``AWS::EFS::FileSystem.BackupPolicy``.
         :param encrypted: ``AWS::EFS::FileSystem.Encrypted``.
         :param file_system_policy: ``AWS::EFS::FileSystem.FileSystemPolicy``.
         :param file_system_tags: ``AWS::EFS::FileSystem.FileSystemTags``.
@@ -964,6 +938,7 @@ class CfnFileSystem(
         :param throughput_mode: ``AWS::EFS::FileSystem.ThroughputMode``.
         """
         props = CfnFileSystemProps(
+            backup_policy=backup_policy,
             encrypted=encrypted,
             file_system_policy=file_system_policy,
             file_system_tags=file_system_tags,
@@ -976,34 +951,6 @@ class CfnFileSystem(
 
         jsii.create(CfnFileSystem, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnFileSystem":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -1030,6 +977,15 @@ class CfnFileSystem(
         """The CloudFormation resource type name for this resource class."""
         return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
 
+    @builtins.property
+    @jsii.member(jsii_name="attrArn")
+    def attr_arn(self) -> str:
+        """
+        cloudformationAttribute:
+        :cloudformationAttribute:: Arn
+        """
+        return jsii.get(self, "attrArn")
+
     @builtins.property
     @jsii.member(jsii_name="attrFileSystemId")
     def attr_file_system_id(self) -> str:
@@ -1068,6 +1024,27 @@ class CfnFileSystem(
     def file_system_policy(self, value: typing.Any) -> None:
         jsii.set(self, "fileSystemPolicy", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="backupPolicy")
+    def backup_policy(
+        self,
+    ) -> typing.Optional[typing.Union["BackupPolicyProperty", _IResolvable_9ceae33e]]:
+        """``AWS::EFS::FileSystem.BackupPolicy``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-filesystem.html#cfn-efs-filesystem-backuppolicy
+        """
+        return jsii.get(self, "backupPolicy")
+
+    @backup_policy.setter
+    def backup_policy(
+        self,
+        value: typing.Optional[
+            typing.Union["BackupPolicyProperty", _IResolvable_9ceae33e]
+        ],
+    ) -> None:
+        jsii.set(self, "backupPolicy", value)
+
     @builtins.property
     @jsii.member(jsii_name="encrypted")
     def encrypted(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
@@ -1173,6 +1150,43 @@ class CfnFileSystem(
     def throughput_mode(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "throughputMode", value)
 
+    @jsii.data_type(
+        jsii_type="monocdk-experiment.aws_efs.CfnFileSystem.BackupPolicyProperty",
+        jsii_struct_bases=[],
+        name_mapping={"status": "status"},
+    )
+    class BackupPolicyProperty:
+        def __init__(self, *, status: str) -> None:
+            """
+            :param status: ``CfnFileSystem.BackupPolicyProperty.Status``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-efs-filesystem-backuppolicy.html
+            """
+            self._values = {
+                "status": status,
+            }
+
+        @builtins.property
+        def status(self) -> str:
+            """``CfnFileSystem.BackupPolicyProperty.Status``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-efs-filesystem-backuppolicy.html#cfn-efs-filesystem-backuppolicy-status
+            """
+            return self._values.get("status")
+
+        def __eq__(self, rhs) -> bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs) -> bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "BackupPolicyProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
     @jsii.data_type(
         jsii_type="monocdk-experiment.aws_efs.CfnFileSystem.ElasticFileSystemTagProperty",
         jsii_struct_bases=[],
@@ -1263,6 +1277,7 @@ class CfnFileSystem(
     jsii_type="monocdk-experiment.aws_efs.CfnFileSystemProps",
     jsii_struct_bases=[],
     name_mapping={
+        "backup_policy": "backupPolicy",
         "encrypted": "encrypted",
         "file_system_policy": "fileSystemPolicy",
         "file_system_tags": "fileSystemTags",
@@ -1277,6 +1292,9 @@ class CfnFileSystemProps:
     def __init__(
         self,
         *,
+        backup_policy: typing.Optional[
+            typing.Union["CfnFileSystem.BackupPolicyProperty", _IResolvable_9ceae33e]
+        ] = None,
         encrypted: typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]] = None,
         file_system_policy: typing.Any = None,
         file_system_tags: typing.Optional[
@@ -1299,6 +1317,7 @@ class CfnFileSystemProps:
     ) -> None:
         """Properties for defining a ``AWS::EFS::FileSystem``.
 
+        :param backup_policy: ``AWS::EFS::FileSystem.BackupPolicy``.
         :param encrypted: ``AWS::EFS::FileSystem.Encrypted``.
         :param file_system_policy: ``AWS::EFS::FileSystem.FileSystemPolicy``.
         :param file_system_tags: ``AWS::EFS::FileSystem.FileSystemTags``.
@@ -1312,6 +1331,8 @@ class CfnFileSystemProps:
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-filesystem.html
         """
         self._values = {}
+        if backup_policy is not None:
+            self._values["backup_policy"] = backup_policy
         if encrypted is not None:
             self._values["encrypted"] = encrypted
         if file_system_policy is not None:
@@ -1331,6 +1352,19 @@ class CfnFileSystemProps:
         if throughput_mode is not None:
             self._values["throughput_mode"] = throughput_mode
 
+    @builtins.property
+    def backup_policy(
+        self,
+    ) -> typing.Optional[
+        typing.Union["CfnFileSystem.BackupPolicyProperty", _IResolvable_9ceae33e]
+    ]:
+        """``AWS::EFS::FileSystem.BackupPolicy``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-filesystem.html#cfn-efs-filesystem-backuppolicy
+        """
+        return self._values.get("backup_policy")
+
     @builtins.property
     def encrypted(self) -> typing.Optional[typing.Union[bool, _IResolvable_9ceae33e]]:
         """``AWS::EFS::FileSystem.Encrypted``.
@@ -1470,34 +1504,6 @@ class CfnMountTarget(
 
         jsii.create(CfnMountTarget, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnMountTarget":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
