@@ -835,6 +835,7 @@ class EcsTask(
         cluster: _ICluster_5cbcc408,
         task_definition: _TaskDefinition_acfbb011,
         container_overrides: typing.Optional[typing.List["ContainerOverride"]] = None,
+        role: typing.Optional[_IRole_e69bbae4] = None,
         security_group: typing.Optional[_ISecurityGroup_d72ab8e8] = None,
         security_groups: typing.Optional[typing.List[_ISecurityGroup_d72ab8e8]] = None,
         subnet_selection: typing.Optional[_SubnetSelection_36a13cd6] = None,
@@ -844,6 +845,7 @@ class EcsTask(
         :param cluster: Cluster where service will be deployed.
         :param task_definition: Task Definition of the task that should be started.
         :param container_overrides: Container setting overrides. Key is the name of the container to override, value is the values you want to override.
+        :param role: Existing IAM role to run the ECS task. Default: A new IAM role is created
         :param security_group: Existing security group to use for the task's ENIs. (Only applicable in case the TaskDefinition is configured for AwsVpc networking) Default: A new security group is created
         :param security_groups: Existing security groups to use for the task's ENIs. (Only applicable in case the TaskDefinition is configured for AwsVpc networking) Default: A new security group is created
         :param subnet_selection: In what subnets to place the task's ENIs. (Only applicable in case the TaskDefinition is configured for AwsVpc networking) Default: Private subnets
@@ -856,6 +858,7 @@ class EcsTask(
             cluster=cluster,
             task_definition=task_definition,
             container_overrides=container_overrides,
+            role=role,
             security_group=security_group,
             security_groups=security_groups,
             subnet_selection=subnet_selection,
@@ -919,6 +922,7 @@ class EcsTask(
         "cluster": "cluster",
         "task_definition": "taskDefinition",
         "container_overrides": "containerOverrides",
+        "role": "role",
         "security_group": "securityGroup",
         "security_groups": "securityGroups",
         "subnet_selection": "subnetSelection",
@@ -932,6 +936,7 @@ class EcsTaskProps:
         cluster: _ICluster_5cbcc408,
         task_definition: _TaskDefinition_acfbb011,
         container_overrides: typing.Optional[typing.List["ContainerOverride"]] = None,
+        role: typing.Optional[_IRole_e69bbae4] = None,
         security_group: typing.Optional[_ISecurityGroup_d72ab8e8] = None,
         security_groups: typing.Optional[typing.List[_ISecurityGroup_d72ab8e8]] = None,
         subnet_selection: typing.Optional[_SubnetSelection_36a13cd6] = None,
@@ -942,6 +947,7 @@ class EcsTaskProps:
         :param cluster: Cluster where service will be deployed.
         :param task_definition: Task Definition of the task that should be started.
         :param container_overrides: Container setting overrides. Key is the name of the container to override, value is the values you want to override.
+        :param role: Existing IAM role to run the ECS task. Default: A new IAM role is created
         :param security_group: Existing security group to use for the task's ENIs. (Only applicable in case the TaskDefinition is configured for AwsVpc networking) Default: A new security group is created
         :param security_groups: Existing security groups to use for the task's ENIs. (Only applicable in case the TaskDefinition is configured for AwsVpc networking) Default: A new security group is created
         :param subnet_selection: In what subnets to place the task's ENIs. (Only applicable in case the TaskDefinition is configured for AwsVpc networking) Default: Private subnets
@@ -958,6 +964,8 @@ class EcsTaskProps:
         }
         if container_overrides is not None:
             self._values["container_overrides"] = container_overrides
+        if role is not None:
+            self._values["role"] = role
         if security_group is not None:
             self._values["security_group"] = security_group
         if security_groups is not None:
@@ -997,6 +1005,18 @@ class EcsTaskProps:
         """
         return self._values.get("container_overrides")
 
+    @builtins.property
+    def role(self) -> typing.Optional[_IRole_e69bbae4]:
+        """Existing IAM role to run the ECS task.
+
+        default
+        :default: A new IAM role is created
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("role")
+
     @builtins.property
     def security_group(self) -> typing.Optional[_ISecurityGroup_d72ab8e8]:
         """Existing security group to use for the task's ENIs.
