@@ -15,8 +15,6 @@ from .. import (
     Construct as _Construct_f50a3f53,
     IResolvable as _IResolvable_9ceae33e,
     CfnTag as _CfnTag_b4661f1a,
-    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
-    ICfnFinder as _ICfnFinder_3b168f30,
     TreeInspector as _TreeInspector_154f5999,
     TagManager as _TagManager_2508893f,
     IInspectable as _IInspectable_051e6ed8,
@@ -97,34 +95,6 @@ class CfnFileSystem(
 
         jsii.create(CfnFileSystem, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnFileSystem":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -323,6 +293,7 @@ class CfnFileSystem(
         jsii_type="monocdk-experiment.aws_fsx.CfnFileSystem.LustreConfigurationProperty",
         jsii_struct_bases=[],
         name_mapping={
+            "auto_import_policy": "autoImportPolicy",
             "automatic_backup_retention_days": "automaticBackupRetentionDays",
             "copy_tags_to_backups": "copyTagsToBackups",
             "daily_automatic_backup_start_time": "dailyAutomaticBackupStartTime",
@@ -338,6 +309,7 @@ class CfnFileSystem(
         def __init__(
             self,
             *,
+            auto_import_policy: typing.Optional[str] = None,
             automatic_backup_retention_days: typing.Optional[jsii.Number] = None,
             copy_tags_to_backups: typing.Optional[
                 typing.Union[bool, _IResolvable_9ceae33e]
@@ -351,6 +323,7 @@ class CfnFileSystem(
             weekly_maintenance_start_time: typing.Optional[str] = None,
         ) -> None:
             """
+            :param auto_import_policy: ``CfnFileSystem.LustreConfigurationProperty.AutoImportPolicy``.
             :param automatic_backup_retention_days: ``CfnFileSystem.LustreConfigurationProperty.AutomaticBackupRetentionDays``.
             :param copy_tags_to_backups: ``CfnFileSystem.LustreConfigurationProperty.CopyTagsToBackups``.
             :param daily_automatic_backup_start_time: ``CfnFileSystem.LustreConfigurationProperty.DailyAutomaticBackupStartTime``.
@@ -365,6 +338,8 @@ class CfnFileSystem(
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fsx-filesystem-lustreconfiguration.html
             """
             self._values = {}
+            if auto_import_policy is not None:
+                self._values["auto_import_policy"] = auto_import_policy
             if automatic_backup_retention_days is not None:
                 self._values[
                     "automatic_backup_retention_days"
@@ -392,6 +367,15 @@ class CfnFileSystem(
                     "weekly_maintenance_start_time"
                 ] = weekly_maintenance_start_time
 
+        @builtins.property
+        def auto_import_policy(self) -> typing.Optional[str]:
+            """``CfnFileSystem.LustreConfigurationProperty.AutoImportPolicy``.
+
+            see
+            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fsx-filesystem-lustreconfiguration.html#cfn-fsx-filesystem-lustreconfiguration-autoimportpolicy
+            """
+            return self._values.get("auto_import_policy")
+
         @builtins.property
         def automatic_backup_retention_days(self) -> typing.Optional[jsii.Number]:
             """``CfnFileSystem.LustreConfigurationProperty.AutomaticBackupRetentionDays``.
@@ -1707,17 +1691,23 @@ class FileSystemBase(
         scope: _Construct_f50a3f53,
         id: str,
         *,
+        account: typing.Optional[str] = None,
         physical_name: typing.Optional[str] = None,
+        region: typing.Optional[str] = None,
     ) -> None:
         """
         :param scope: -
         :param id: -
+        :param account: The AWS account ID this resource belongs to. Default: - the resource is in the same account as the stack it belongs to
         :param physical_name: The value passed in by users to the physical name prop of the resource. - ``undefined`` implies that a physical name will be allocated by CloudFormation during deployment. - a concrete value implies a specific physical name - ``PhysicalName.GENERATE_IF_NEEDED`` is a marker that indicates that a physical will only be generated by the CDK if it is needed for cross-environment references. Otherwise, it will be allocated by CloudFormation. Default: - The physical name will be allocated by CloudFormation at deployment time
+        :param region: The AWS region this resource belongs to. Default: - the resource is in the same region as the stack it belongs to
 
         stability
         :stability: experimental
         """
-        props = _ResourceProps_92be6f66(physical_name=physical_name)
+        props = _ResourceProps_92be6f66(
+            account=account, physical_name=physical_name, region=region
+        )
 
         jsii.create(FileSystemBase, self, [scope, id, props])
 
