@@ -13,8 +13,6 @@ from .._jsii import *
 from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
-    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
-    ICfnFinder as _ICfnFinder_3b168f30,
     TreeInspector as _TreeInspector_154f5999,
     IInspectable as _IInspectable_051e6ed8,
     IResolvable as _IResolvable_9ceae33e,
@@ -58,34 +56,6 @@ class CfnAssessmentTarget(
 
         jsii.create(CfnAssessmentTarget, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnAssessmentTarget":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -264,34 +234,6 @@ class CfnAssessmentTemplate(
 
         jsii.create(CfnAssessmentTemplate, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnAssessmentTemplate":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -563,34 +505,6 @@ class CfnResourceGroup(
 
         jsii.create(CfnResourceGroup, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnResourceGroup":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
