@@ -59,6 +59,7 @@ class Bundling(
         build_args: typing.Optional[typing.Mapping[str, str]] = None,
         cache_dir: typing.Optional[str] = None,
         external_modules: typing.Optional[typing.List[str]] = None,
+        force_docker_bundling: typing.Optional[bool] = None,
         minify: typing.Optional[bool] = None,
         node_modules: typing.Optional[typing.List[str]] = None,
         parcel_environment: typing.Optional[typing.Mapping[str, str]] = None,
@@ -71,12 +72,13 @@ class Bundling(
         :param entry: Entry file.
         :param runtime: The runtime of the lambda function.
         :param build_args: Build arguments to pass when building the bundling image. Default: - no build arguments are passed
-        :param cache_dir: The cache directory. Parcel uses a filesystem cache for fast rebuilds. Default: - ``.cache`` in the root directory
+        :param cache_dir: The cache directory (relative to the project root). Parcel uses a filesystem cache for fast rebuilds. Default: - ``.parcel-cache`` in the working directory
         :param external_modules: A list of modules that should be considered as externals (already available in the runtime). Default: ['aws-sdk']
+        :param force_docker_bundling: Force bundling in a Docker container even if local bundling is possible.This is useful if your function relies on node modules that should be installed (``nodeModules``) in a Lambda compatible environment. Default: false
         :param minify: Whether to minify files when bundling. Default: false
         :param node_modules: A list of modules that should be installed instead of bundled. Modules are installed in a Lambda compatible environnment. Default: - all modules are bundled
         :param parcel_environment: Environment variables defined when Parcel runs. Default: - no environment variables are defined.
-        :param parcel_version: The version of Parcel to use. Default: - 2.0.0-beta.1
+        :param parcel_version: The version of Parcel to use when running in a Docker container. Default: - 2.0.0-beta.1
         :param project_root: The root of the project. This will be used as the source for the volume mounted in the Docker container. If you specify this prop, ensure that this path includes ``entry`` and any module/dependencies used by your function otherwise bundling will not be possible. Default: - the closest path containing a .git folder
         :param source_maps: Whether to include source maps when bundling. Default: false
 
@@ -89,6 +91,7 @@ class Bundling(
             build_args=build_args,
             cache_dir=cache_dir,
             external_modules=external_modules,
+            force_docker_bundling=force_docker_bundling,
             minify=minify,
             node_modules=node_modules,
             parcel_environment=parcel_environment,
@@ -149,6 +152,7 @@ class NodejsFunction(
         build_args: typing.Optional[typing.Mapping[str, str]] = None,
         cache_dir: typing.Optional[str] = None,
         external_modules: typing.Optional[typing.List[str]] = None,
+        force_docker_bundling: typing.Optional[bool] = None,
         minify: typing.Optional[bool] = None,
         node_modules: typing.Optional[typing.List[str]] = None,
         parcel_environment: typing.Optional[typing.Mapping[str, str]] = None,
@@ -192,12 +196,13 @@ class NodejsFunction(
         :param vpc: VPC network to place Lambda network interfaces. Specify this if the Lambda function needs to access resources in a VPC. Default: - Function is not placed within a VPC.
         :param vpc_subnets: Where to place the network interfaces within the VPC. Only used if 'vpc' is supplied. Note: internet access for Lambdas requires a NAT gateway, so picking Public subnets is not allowed. Default: - the Vpc default strategy if not specified
         :param build_args: Build arguments to pass when building the bundling image. Default: - no build arguments are passed
-        :param cache_dir: The cache directory. Parcel uses a filesystem cache for fast rebuilds. Default: - ``.cache`` in the root directory
+        :param cache_dir: The cache directory (relative to the project root). Parcel uses a filesystem cache for fast rebuilds. Default: - ``.parcel-cache`` in the working directory
         :param external_modules: A list of modules that should be considered as externals (already available in the runtime). Default: ['aws-sdk']
+        :param force_docker_bundling: Force bundling in a Docker container even if local bundling is possible.This is useful if your function relies on node modules that should be installed (``nodeModules``) in a Lambda compatible environment. Default: false
         :param minify: Whether to minify files when bundling. Default: false
         :param node_modules: A list of modules that should be installed instead of bundled. Modules are installed in a Lambda compatible environnment. Default: - all modules are bundled
         :param parcel_environment: Environment variables defined when Parcel runs. Default: - no environment variables are defined.
-        :param parcel_version: The version of Parcel to use. Default: - 2.0.0-beta.1
+        :param parcel_version: The version of Parcel to use when running in a Docker container. Default: - 2.0.0-beta.1
         :param project_root: The root of the project. This will be used as the source for the volume mounted in the Docker container. If you specify this prop, ensure that this path includes ``entry`` and any module/dependencies used by your function otherwise bundling will not be possible. Default: - the closest path containing a .git folder
         :param source_maps: Whether to include source maps when bundling. Default: false
         :param max_event_age: The maximum age of a request that Lambda sends to a function for processing. Minimum: 60 seconds Maximum: 6 hours Default: Duration.hours(6)
@@ -240,6 +245,7 @@ class NodejsFunction(
             build_args=build_args,
             cache_dir=cache_dir,
             external_modules=external_modules,
+            force_docker_bundling=force_docker_bundling,
             minify=minify,
             node_modules=node_modules,
             parcel_environment=parcel_environment,
@@ -262,6 +268,7 @@ class NodejsFunction(
         "build_args": "buildArgs",
         "cache_dir": "cacheDir",
         "external_modules": "externalModules",
+        "force_docker_bundling": "forceDockerBundling",
         "minify": "minify",
         "node_modules": "nodeModules",
         "parcel_environment": "parcelEnvironment",
@@ -277,6 +284,7 @@ class ParcelBaseOptions:
         build_args: typing.Optional[typing.Mapping[str, str]] = None,
         cache_dir: typing.Optional[str] = None,
         external_modules: typing.Optional[typing.List[str]] = None,
+        force_docker_bundling: typing.Optional[bool] = None,
         minify: typing.Optional[bool] = None,
         node_modules: typing.Optional[typing.List[str]] = None,
         parcel_environment: typing.Optional[typing.Mapping[str, str]] = None,
@@ -287,12 +295,13 @@ class ParcelBaseOptions:
         """Base options for Parcel bundling.
 
         :param build_args: Build arguments to pass when building the bundling image. Default: - no build arguments are passed
-        :param cache_dir: The cache directory. Parcel uses a filesystem cache for fast rebuilds. Default: - ``.cache`` in the root directory
+        :param cache_dir: The cache directory (relative to the project root). Parcel uses a filesystem cache for fast rebuilds. Default: - ``.parcel-cache`` in the working directory
         :param external_modules: A list of modules that should be considered as externals (already available in the runtime). Default: ['aws-sdk']
+        :param force_docker_bundling: Force bundling in a Docker container even if local bundling is possible.This is useful if your function relies on node modules that should be installed (``nodeModules``) in a Lambda compatible environment. Default: false
         :param minify: Whether to minify files when bundling. Default: false
         :param node_modules: A list of modules that should be installed instead of bundled. Modules are installed in a Lambda compatible environnment. Default: - all modules are bundled
         :param parcel_environment: Environment variables defined when Parcel runs. Default: - no environment variables are defined.
-        :param parcel_version: The version of Parcel to use. Default: - 2.0.0-beta.1
+        :param parcel_version: The version of Parcel to use when running in a Docker container. Default: - 2.0.0-beta.1
         :param project_root: The root of the project. This will be used as the source for the volume mounted in the Docker container. If you specify this prop, ensure that this path includes ``entry`` and any module/dependencies used by your function otherwise bundling will not be possible. Default: - the closest path containing a .git folder
         :param source_maps: Whether to include source maps when bundling. Default: false
 
@@ -306,6 +315,8 @@ class ParcelBaseOptions:
             self._values["cache_dir"] = cache_dir
         if external_modules is not None:
             self._values["external_modules"] = external_modules
+        if force_docker_bundling is not None:
+            self._values["force_docker_bundling"] = force_docker_bundling
         if minify is not None:
             self._values["minify"] = minify
         if node_modules is not None:
@@ -333,12 +344,12 @@ class ParcelBaseOptions:
 
     @builtins.property
     def cache_dir(self) -> typing.Optional[str]:
-        """The cache directory.
+        """The cache directory (relative to the project root).
 
         Parcel uses a filesystem cache for fast rebuilds.
 
         default
-        :default: - ``.cache`` in the root directory
+        :default: - ``.parcel-cache`` in the working directory
 
         stability
         :stability: experimental
@@ -357,6 +368,18 @@ class ParcelBaseOptions:
         """
         return self._values.get("external_modules")
 
+    @builtins.property
+    def force_docker_bundling(self) -> typing.Optional[bool]:
+        """Force bundling in a Docker container even if local bundling is possible.This  is useful if your function relies on node modules that should be installed (``nodeModules``) in a Lambda compatible environment.
+
+        default
+        :default: false
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("force_docker_bundling")
+
     @builtins.property
     def minify(self) -> typing.Optional[bool]:
         """Whether to minify files when bundling.
@@ -398,7 +421,7 @@ class ParcelBaseOptions:
 
     @builtins.property
     def parcel_version(self) -> typing.Optional[str]:
-        """The version of Parcel to use.
+        """The version of Parcel to use when running in a Docker container.
 
         default
         :default: - 2.0.0-beta.1
@@ -456,6 +479,7 @@ class ParcelBaseOptions:
         "build_args": "buildArgs",
         "cache_dir": "cacheDir",
         "external_modules": "externalModules",
+        "force_docker_bundling": "forceDockerBundling",
         "minify": "minify",
         "node_modules": "nodeModules",
         "parcel_environment": "parcelEnvironment",
@@ -473,6 +497,7 @@ class ParcelOptions(ParcelBaseOptions):
         build_args: typing.Optional[typing.Mapping[str, str]] = None,
         cache_dir: typing.Optional[str] = None,
         external_modules: typing.Optional[typing.List[str]] = None,
+        force_docker_bundling: typing.Optional[bool] = None,
         minify: typing.Optional[bool] = None,
         node_modules: typing.Optional[typing.List[str]] = None,
         parcel_environment: typing.Optional[typing.Mapping[str, str]] = None,
@@ -485,12 +510,13 @@ class ParcelOptions(ParcelBaseOptions):
         """Options for Parcel bundling.
 
         :param build_args: Build arguments to pass when building the bundling image. Default: - no build arguments are passed
-        :param cache_dir: The cache directory. Parcel uses a filesystem cache for fast rebuilds. Default: - ``.cache`` in the root directory
+        :param cache_dir: The cache directory (relative to the project root). Parcel uses a filesystem cache for fast rebuilds. Default: - ``.parcel-cache`` in the working directory
         :param external_modules: A list of modules that should be considered as externals (already available in the runtime). Default: ['aws-sdk']
+        :param force_docker_bundling: Force bundling in a Docker container even if local bundling is possible.This is useful if your function relies on node modules that should be installed (``nodeModules``) in a Lambda compatible environment. Default: false
         :param minify: Whether to minify files when bundling. Default: false
         :param node_modules: A list of modules that should be installed instead of bundled. Modules are installed in a Lambda compatible environnment. Default: - all modules are bundled
         :param parcel_environment: Environment variables defined when Parcel runs. Default: - no environment variables are defined.
-        :param parcel_version: The version of Parcel to use. Default: - 2.0.0-beta.1
+        :param parcel_version: The version of Parcel to use when running in a Docker container. Default: - 2.0.0-beta.1
         :param project_root: The root of the project. This will be used as the source for the volume mounted in the Docker container. If you specify this prop, ensure that this path includes ``entry`` and any module/dependencies used by your function otherwise bundling will not be possible. Default: - the closest path containing a .git folder
         :param source_maps: Whether to include source maps when bundling. Default: false
         :param entry: Entry file.
@@ -509,6 +535,8 @@ class ParcelOptions(ParcelBaseOptions):
             self._values["cache_dir"] = cache_dir
         if external_modules is not None:
             self._values["external_modules"] = external_modules
+        if force_docker_bundling is not None:
+            self._values["force_docker_bundling"] = force_docker_bundling
         if minify is not None:
             self._values["minify"] = minify
         if node_modules is not None:
@@ -536,12 +564,12 @@ class ParcelOptions(ParcelBaseOptions):
 
     @builtins.property
     def cache_dir(self) -> typing.Optional[str]:
-        """The cache directory.
+        """The cache directory (relative to the project root).
 
         Parcel uses a filesystem cache for fast rebuilds.
 
         default
-        :default: - ``.cache`` in the root directory
+        :default: - ``.parcel-cache`` in the working directory
 
         stability
         :stability: experimental
@@ -560,6 +588,18 @@ class ParcelOptions(ParcelBaseOptions):
         """
         return self._values.get("external_modules")
 
+    @builtins.property
+    def force_docker_bundling(self) -> typing.Optional[bool]:
+        """Force bundling in a Docker container even if local bundling is possible.This  is useful if your function relies on node modules that should be installed (``nodeModules``) in a Lambda compatible environment.
+
+        default
+        :default: false
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("force_docker_bundling")
+
     @builtins.property
     def minify(self) -> typing.Optional[bool]:
         """Whether to minify files when bundling.
@@ -601,7 +641,7 @@ class ParcelOptions(ParcelBaseOptions):
 
     @builtins.property
     def parcel_version(self) -> typing.Optional[str]:
-        """The version of Parcel to use.
+        """The version of Parcel to use when running in a Docker container.
 
         default
         :default: - 2.0.0-beta.1
@@ -705,6 +745,7 @@ class ParcelOptions(ParcelBaseOptions):
         "build_args": "buildArgs",
         "cache_dir": "cacheDir",
         "external_modules": "externalModules",
+        "force_docker_bundling": "forceDockerBundling",
         "minify": "minify",
         "node_modules": "nodeModules",
         "parcel_environment": "parcelEnvironment",
@@ -754,6 +795,7 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         build_args: typing.Optional[typing.Mapping[str, str]] = None,
         cache_dir: typing.Optional[str] = None,
         external_modules: typing.Optional[typing.List[str]] = None,
+        force_docker_bundling: typing.Optional[bool] = None,
         minify: typing.Optional[bool] = None,
         node_modules: typing.Optional[typing.List[str]] = None,
         parcel_environment: typing.Optional[typing.Mapping[str, str]] = None,
@@ -796,12 +838,13 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         :param vpc: VPC network to place Lambda network interfaces. Specify this if the Lambda function needs to access resources in a VPC. Default: - Function is not placed within a VPC.
         :param vpc_subnets: Where to place the network interfaces within the VPC. Only used if 'vpc' is supplied. Note: internet access for Lambdas requires a NAT gateway, so picking Public subnets is not allowed. Default: - the Vpc default strategy if not specified
         :param build_args: Build arguments to pass when building the bundling image. Default: - no build arguments are passed
-        :param cache_dir: The cache directory. Parcel uses a filesystem cache for fast rebuilds. Default: - ``.cache`` in the root directory
+        :param cache_dir: The cache directory (relative to the project root). Parcel uses a filesystem cache for fast rebuilds. Default: - ``.parcel-cache`` in the working directory
         :param external_modules: A list of modules that should be considered as externals (already available in the runtime). Default: ['aws-sdk']
+        :param force_docker_bundling: Force bundling in a Docker container even if local bundling is possible.This is useful if your function relies on node modules that should be installed (``nodeModules``) in a Lambda compatible environment. Default: false
         :param minify: Whether to minify files when bundling. Default: false
         :param node_modules: A list of modules that should be installed instead of bundled. Modules are installed in a Lambda compatible environnment. Default: - all modules are bundled
         :param parcel_environment: Environment variables defined when Parcel runs. Default: - no environment variables are defined.
-        :param parcel_version: The version of Parcel to use. Default: - 2.0.0-beta.1
+        :param parcel_version: The version of Parcel to use when running in a Docker container. Default: - 2.0.0-beta.1
         :param project_root: The root of the project. This will be used as the source for the volume mounted in the Docker container. If you specify this prop, ensure that this path includes ``entry`` and any module/dependencies used by your function otherwise bundling will not be possible. Default: - the closest path containing a .git folder
         :param source_maps: Whether to include source maps when bundling. Default: false
         :param aws_sdk_connection_reuse: Whether to automatically reuse TCP connections when working with the AWS SDK for JavaScript. This sets the ``AWS_NODEJS_CONNECTION_REUSE_ENABLED`` environment variable to ``1``. Default: true
@@ -887,6 +930,8 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
             self._values["cache_dir"] = cache_dir
         if external_modules is not None:
             self._values["external_modules"] = external_modules
+        if force_docker_bundling is not None:
+            self._values["force_docker_bundling"] = force_docker_bundling
         if minify is not None:
             self._values["minify"] = minify
         if node_modules is not None:
@@ -1342,12 +1387,12 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
 
     @builtins.property
     def cache_dir(self) -> typing.Optional[str]:
-        """The cache directory.
+        """The cache directory (relative to the project root).
 
         Parcel uses a filesystem cache for fast rebuilds.
 
         default
-        :default: - ``.cache`` in the root directory
+        :default: - ``.parcel-cache`` in the working directory
 
         stability
         :stability: experimental
@@ -1366,6 +1411,18 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
         """
         return self._values.get("external_modules")
 
+    @builtins.property
+    def force_docker_bundling(self) -> typing.Optional[bool]:
+        """Force bundling in a Docker container even if local bundling is possible.This  is useful if your function relies on node modules that should be installed (``nodeModules``) in a Lambda compatible environment.
+
+        default
+        :default: false
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("force_docker_bundling")
+
     @builtins.property
     def minify(self) -> typing.Optional[bool]:
         """Whether to minify files when bundling.
@@ -1407,7 +1464,7 @@ class NodejsFunctionProps(_FunctionOptions_83fb7178, ParcelBaseOptions):
 
     @builtins.property
     def parcel_version(self) -> typing.Optional[str]:
-        """The version of Parcel to use.
+        """The version of Parcel to use when running in a Docker container.
 
         default
         :default: - 2.0.0-beta.1
