@@ -10,20 +10,27 @@ import publication
 
 from .._jsii import *
 
-from ..aws_kms import (IKey as _IKey_3336c79d)
-from ..aws_lambda import (IFunction as _IFunction_1c1de0bc)
-from ..aws_s3 import (IBucket as _IBucket_25bad983)
-from ..aws_ses import (ReceiptRuleActionConfig as _ReceiptRuleActionConfig_2ed15321, IReceiptRule as _IReceiptRule_fc1cf2e3, IReceiptRuleAction as _IReceiptRuleAction_cc1b8803)
-from ..aws_sns import (ITopic as _ITopic_ef0ebe0e)
+from ..aws_kms import IKey as _IKey_3336c79d
+from ..aws_lambda import IFunction as _IFunction_1c1de0bc
+from ..aws_s3 import IBucket as _IBucket_25bad983
+from ..aws_ses import (
+    ReceiptRuleActionConfig as _ReceiptRuleActionConfig_2ed15321,
+    IReceiptRule as _IReceiptRule_fc1cf2e3,
+    IReceiptRuleAction as _IReceiptRuleAction_cc1b8803,
+)
+from ..aws_sns import ITopic as _ITopic_ef0ebe0e
 
 
 @jsii.implements(_IReceiptRuleAction_cc1b8803)
-class AddHeader(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.AddHeader"):
+class AddHeader(
+    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.AddHeader"
+):
     """Adds a header to the received email.
 
     stability
     :stability: experimental
     """
+
     def __init__(self, *, name: str, value: str) -> None:
         """
         :param name: The name of the header to add. Must be between 1 and 50 characters, inclusive, and consist of alphanumeric (a-z, A-Z, 0-9) characters and dashes only.
@@ -48,8 +55,12 @@ class AddHeader(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_a
         return jsii.invoke(self, "bind", [_rule])
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_ses_actions.AddHeaderProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'value': 'value'})
-class AddHeaderProps():
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_ses_actions.AddHeaderProps",
+    jsii_struct_bases=[],
+    name_mapping={"name": "name", "value": "value"},
+)
+class AddHeaderProps:
     def __init__(self, *, name: str, value: str) -> None:
         """Construction properties for a add header action.
 
@@ -60,8 +71,8 @@ class AddHeaderProps():
         :stability: experimental
         """
         self._values = {
-            'name': name,
-            'value': value,
+            "name": name,
+            "value": value,
         }
 
     @builtins.property
@@ -75,7 +86,7 @@ class AddHeaderProps():
         stability
         :stability: experimental
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     @builtins.property
     def value(self) -> str:
@@ -87,7 +98,7 @@ class AddHeaderProps():
         stability
         :stability: experimental
         """
-        return self._values.get('value')
+        return self._values.get("value")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -96,17 +107,28 @@ class AddHeaderProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'AddHeaderProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "AddHeaderProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IReceiptRuleAction_cc1b8803)
-class Bounce(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.Bounce"):
+class Bounce(
+    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.Bounce"
+):
     """Rejects the received email by returning a bounce response to the sender and, optionally, publishes a notification to Amazon SNS.
 
     stability
     :stability: experimental
     """
-    def __init__(self, *, sender: str, template: "BounceTemplate", topic: typing.Optional[_ITopic_ef0ebe0e]=None) -> None:
+
+    def __init__(
+        self,
+        *,
+        sender: str,
+        template: "BounceTemplate",
+        topic: typing.Optional[_ITopic_ef0ebe0e] = None,
+    ) -> None:
         """
         :param sender: The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
         :param template: The template containing the message, reply code and status code.
@@ -131,9 +153,19 @@ class Bounce(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_acti
         return jsii.invoke(self, "bind", [_rule])
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_ses_actions.BounceProps", jsii_struct_bases=[], name_mapping={'sender': 'sender', 'template': 'template', 'topic': 'topic'})
-class BounceProps():
-    def __init__(self, *, sender: str, template: "BounceTemplate", topic: typing.Optional[_ITopic_ef0ebe0e]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_ses_actions.BounceProps",
+    jsii_struct_bases=[],
+    name_mapping={"sender": "sender", "template": "template", "topic": "topic"},
+)
+class BounceProps:
+    def __init__(
+        self,
+        *,
+        sender: str,
+        template: "BounceTemplate",
+        topic: typing.Optional[_ITopic_ef0ebe0e] = None,
+    ) -> None:
         """Construction properties for a bounce action.
 
         :param sender: The email address of the sender of the bounced email. This is the address from which the bounce message will be sent.
@@ -144,10 +176,11 @@ class BounceProps():
         :stability: experimental
         """
         self._values = {
-            'sender': sender,
-            'template': template,
+            "sender": sender,
+            "template": template,
         }
-        if topic is not None: self._values["topic"] = topic
+        if topic is not None:
+            self._values["topic"] = topic
 
     @builtins.property
     def sender(self) -> str:
@@ -159,7 +192,7 @@ class BounceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('sender')
+        return self._values.get("sender")
 
     @builtins.property
     def template(self) -> "BounceTemplate":
@@ -168,7 +201,7 @@ class BounceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('template')
+        return self._values.get("template")
 
     @builtins.property
     def topic(self) -> typing.Optional[_ITopic_ef0ebe0e]:
@@ -180,7 +213,7 @@ class BounceProps():
         stability
         :stability: experimental
         """
-        return self._values.get('topic')
+        return self._values.get("topic")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -189,16 +222,28 @@ class BounceProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'BounceProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "BounceProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
-class BounceTemplate(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.BounceTemplate"):
+class BounceTemplate(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="monocdk-experiment.aws_ses_actions.BounceTemplate",
+):
     """A bounce template.
 
     stability
     :stability: experimental
     """
-    def __init__(self, *, message: str, smtp_reply_code: str, status_code: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        *,
+        message: str,
+        smtp_reply_code: str,
+        status_code: typing.Optional[str] = None,
+    ) -> None:
         """
         :param message: Human-readable text to include in the bounce message.
         :param smtp_reply_code: The SMTP reply code, as defined by RFC 5321.
@@ -207,7 +252,9 @@ class BounceTemplate(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_
         stability
         :stability: experimental
         """
-        props = BounceTemplateProps(message=message, smtp_reply_code=smtp_reply_code, status_code=status_code)
+        props = BounceTemplateProps(
+            message=message, smtp_reply_code=smtp_reply_code, status_code=status_code
+        )
 
         jsii.create(BounceTemplate, self, [props])
 
@@ -266,9 +313,23 @@ class BounceTemplate(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_
         return jsii.get(self, "props")
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_ses_actions.BounceTemplateProps", jsii_struct_bases=[], name_mapping={'message': 'message', 'smtp_reply_code': 'smtpReplyCode', 'status_code': 'statusCode'})
-class BounceTemplateProps():
-    def __init__(self, *, message: str, smtp_reply_code: str, status_code: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_ses_actions.BounceTemplateProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "message": "message",
+        "smtp_reply_code": "smtpReplyCode",
+        "status_code": "statusCode",
+    },
+)
+class BounceTemplateProps:
+    def __init__(
+        self,
+        *,
+        message: str,
+        smtp_reply_code: str,
+        status_code: typing.Optional[str] = None,
+    ) -> None:
         """Construction properties for a BounceTemplate.
 
         :param message: Human-readable text to include in the bounce message.
@@ -279,10 +340,11 @@ class BounceTemplateProps():
         :stability: experimental
         """
         self._values = {
-            'message': message,
-            'smtp_reply_code': smtp_reply_code,
+            "message": message,
+            "smtp_reply_code": smtp_reply_code,
         }
-        if status_code is not None: self._values["status_code"] = status_code
+        if status_code is not None:
+            self._values["status_code"] = status_code
 
     @builtins.property
     def message(self) -> str:
@@ -291,7 +353,7 @@ class BounceTemplateProps():
         stability
         :stability: experimental
         """
-        return self._values.get('message')
+        return self._values.get("message")
 
     @builtins.property
     def smtp_reply_code(self) -> str:
@@ -302,7 +364,7 @@ class BounceTemplateProps():
         stability
         :stability: experimental
         """
-        return self._values.get('smtp_reply_code')
+        return self._values.get("smtp_reply_code")
 
     @builtins.property
     def status_code(self) -> typing.Optional[str]:
@@ -313,7 +375,7 @@ class BounceTemplateProps():
         stability
         :stability: experimental
         """
-        return self._values.get('status_code')
+        return self._values.get("status_code")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -322,7 +384,9 @@ class BounceTemplateProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'BounceTemplateProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "BounceTemplateProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.enum(jsii_type="monocdk-experiment.aws_ses_actions.EmailEncoding")
@@ -332,6 +396,7 @@ class EmailEncoding(enum.Enum):
     stability
     :stability: experimental
     """
+
     BASE64 = "BASE64"
     """Base 64.
 
@@ -345,14 +410,24 @@ class EmailEncoding(enum.Enum):
     :stability: experimental
     """
 
+
 @jsii.implements(_IReceiptRuleAction_cc1b8803)
-class Lambda(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.Lambda"):
+class Lambda(
+    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.Lambda"
+):
     """Calls an AWS Lambda function, and optionally, publishes a notification to Amazon SNS.
 
     stability
     :stability: experimental
     """
-    def __init__(self, *, function: _IFunction_1c1de0bc, invocation_type: typing.Optional["LambdaInvocationType"]=None, topic: typing.Optional[_ITopic_ef0ebe0e]=None) -> None:
+
+    def __init__(
+        self,
+        *,
+        function: _IFunction_1c1de0bc,
+        invocation_type: typing.Optional["LambdaInvocationType"] = None,
+        topic: typing.Optional[_ITopic_ef0ebe0e] = None,
+    ) -> None:
         """
         :param function: The Lambda function to invoke.
         :param invocation_type: The invocation type of the Lambda function. Default: Event
@@ -361,7 +436,9 @@ class Lambda(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_acti
         stability
         :stability: experimental
         """
-        props = LambdaProps(function=function, invocation_type=invocation_type, topic=topic)
+        props = LambdaProps(
+            function=function, invocation_type=invocation_type, topic=topic
+        )
 
         jsii.create(Lambda, self, [props])
 
@@ -384,6 +461,7 @@ class LambdaInvocationType(enum.Enum):
     stability
     :stability: experimental
     """
+
     EVENT = "EVENT"
     """The function will be invoked asynchronously.
 
@@ -401,9 +479,24 @@ class LambdaInvocationType(enum.Enum):
     :stability: experimental
     """
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_ses_actions.LambdaProps", jsii_struct_bases=[], name_mapping={'function': 'function', 'invocation_type': 'invocationType', 'topic': 'topic'})
-class LambdaProps():
-    def __init__(self, *, function: _IFunction_1c1de0bc, invocation_type: typing.Optional["LambdaInvocationType"]=None, topic: typing.Optional[_ITopic_ef0ebe0e]=None) -> None:
+
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_ses_actions.LambdaProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "function": "function",
+        "invocation_type": "invocationType",
+        "topic": "topic",
+    },
+)
+class LambdaProps:
+    def __init__(
+        self,
+        *,
+        function: _IFunction_1c1de0bc,
+        invocation_type: typing.Optional["LambdaInvocationType"] = None,
+        topic: typing.Optional[_ITopic_ef0ebe0e] = None,
+    ) -> None:
         """Construction properties for a Lambda action.
 
         :param function: The Lambda function to invoke.
@@ -414,10 +507,12 @@ class LambdaProps():
         :stability: experimental
         """
         self._values = {
-            'function': function,
+            "function": function,
         }
-        if invocation_type is not None: self._values["invocation_type"] = invocation_type
-        if topic is not None: self._values["topic"] = topic
+        if invocation_type is not None:
+            self._values["invocation_type"] = invocation_type
+        if topic is not None:
+            self._values["topic"] = topic
 
     @builtins.property
     def function(self) -> _IFunction_1c1de0bc:
@@ -426,7 +521,7 @@ class LambdaProps():
         stability
         :stability: experimental
         """
-        return self._values.get('function')
+        return self._values.get("function")
 
     @builtins.property
     def invocation_type(self) -> typing.Optional["LambdaInvocationType"]:
@@ -438,7 +533,7 @@ class LambdaProps():
         stability
         :stability: experimental
         """
-        return self._values.get('invocation_type')
+        return self._values.get("invocation_type")
 
     @builtins.property
     def topic(self) -> typing.Optional[_ITopic_ef0ebe0e]:
@@ -450,7 +545,7 @@ class LambdaProps():
         stability
         :stability: experimental
         """
-        return self._values.get('topic')
+        return self._values.get("topic")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -459,7 +554,9 @@ class LambdaProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'LambdaProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "LambdaProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IReceiptRuleAction_cc1b8803)
@@ -469,7 +566,15 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.
     stability
     :stability: experimental
     """
-    def __init__(self, *, bucket: _IBucket_25bad983, kms_key: typing.Optional[_IKey_3336c79d]=None, object_key_prefix: typing.Optional[str]=None, topic: typing.Optional[_ITopic_ef0ebe0e]=None) -> None:
+
+    def __init__(
+        self,
+        *,
+        bucket: _IBucket_25bad983,
+        kms_key: typing.Optional[_IKey_3336c79d] = None,
+        object_key_prefix: typing.Optional[str] = None,
+        topic: typing.Optional[_ITopic_ef0ebe0e] = None,
+    ) -> None:
         """
         :param bucket: The S3 bucket that incoming email will be saved to.
         :param kms_key: The master key that SES should use to encrypt your emails before saving them to the S3 bucket. Default: no encryption
@@ -479,7 +584,12 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.
         stability
         :stability: experimental
         """
-        props = S3Props(bucket=bucket, kms_key=kms_key, object_key_prefix=object_key_prefix, topic=topic)
+        props = S3Props(
+            bucket=bucket,
+            kms_key=kms_key,
+            object_key_prefix=object_key_prefix,
+            topic=topic,
+        )
 
         jsii.create(S3, self, [props])
 
@@ -495,9 +605,25 @@ class S3(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.
         return jsii.invoke(self, "bind", [rule])
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_ses_actions.S3Props", jsii_struct_bases=[], name_mapping={'bucket': 'bucket', 'kms_key': 'kmsKey', 'object_key_prefix': 'objectKeyPrefix', 'topic': 'topic'})
-class S3Props():
-    def __init__(self, *, bucket: _IBucket_25bad983, kms_key: typing.Optional[_IKey_3336c79d]=None, object_key_prefix: typing.Optional[str]=None, topic: typing.Optional[_ITopic_ef0ebe0e]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_ses_actions.S3Props",
+    jsii_struct_bases=[],
+    name_mapping={
+        "bucket": "bucket",
+        "kms_key": "kmsKey",
+        "object_key_prefix": "objectKeyPrefix",
+        "topic": "topic",
+    },
+)
+class S3Props:
+    def __init__(
+        self,
+        *,
+        bucket: _IBucket_25bad983,
+        kms_key: typing.Optional[_IKey_3336c79d] = None,
+        object_key_prefix: typing.Optional[str] = None,
+        topic: typing.Optional[_ITopic_ef0ebe0e] = None,
+    ) -> None:
         """Construction properties for a S3 action.
 
         :param bucket: The S3 bucket that incoming email will be saved to.
@@ -509,11 +635,14 @@ class S3Props():
         :stability: experimental
         """
         self._values = {
-            'bucket': bucket,
+            "bucket": bucket,
         }
-        if kms_key is not None: self._values["kms_key"] = kms_key
-        if object_key_prefix is not None: self._values["object_key_prefix"] = object_key_prefix
-        if topic is not None: self._values["topic"] = topic
+        if kms_key is not None:
+            self._values["kms_key"] = kms_key
+        if object_key_prefix is not None:
+            self._values["object_key_prefix"] = object_key_prefix
+        if topic is not None:
+            self._values["topic"] = topic
 
     @builtins.property
     def bucket(self) -> _IBucket_25bad983:
@@ -522,7 +651,7 @@ class S3Props():
         stability
         :stability: experimental
         """
-        return self._values.get('bucket')
+        return self._values.get("bucket")
 
     @builtins.property
     def kms_key(self) -> typing.Optional[_IKey_3336c79d]:
@@ -534,7 +663,7 @@ class S3Props():
         stability
         :stability: experimental
         """
-        return self._values.get('kms_key')
+        return self._values.get("kms_key")
 
     @builtins.property
     def object_key_prefix(self) -> typing.Optional[str]:
@@ -546,7 +675,7 @@ class S3Props():
         stability
         :stability: experimental
         """
-        return self._values.get('object_key_prefix')
+        return self._values.get("object_key_prefix")
 
     @builtins.property
     def topic(self) -> typing.Optional[_ITopic_ef0ebe0e]:
@@ -558,7 +687,7 @@ class S3Props():
         stability
         :stability: experimental
         """
-        return self._values.get('topic')
+        return self._values.get("topic")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -567,7 +696,9 @@ class S3Props():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'S3Props(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "S3Props(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IReceiptRuleAction_cc1b8803)
@@ -577,7 +708,13 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions
     stability
     :stability: experimental
     """
-    def __init__(self, *, topic: _ITopic_ef0ebe0e, encoding: typing.Optional["EmailEncoding"]=None) -> None:
+
+    def __init__(
+        self,
+        *,
+        topic: _ITopic_ef0ebe0e,
+        encoding: typing.Optional["EmailEncoding"] = None,
+    ) -> None:
         """
         :param topic: The SNS topic to notify.
         :param encoding: The encoding to use for the email within the Amazon SNS notification. Default: UTF-8
@@ -601,9 +738,18 @@ class Sns(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions
         return jsii.invoke(self, "bind", [_rule])
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_ses_actions.SnsProps", jsii_struct_bases=[], name_mapping={'topic': 'topic', 'encoding': 'encoding'})
-class SnsProps():
-    def __init__(self, *, topic: _ITopic_ef0ebe0e, encoding: typing.Optional["EmailEncoding"]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_ses_actions.SnsProps",
+    jsii_struct_bases=[],
+    name_mapping={"topic": "topic", "encoding": "encoding"},
+)
+class SnsProps:
+    def __init__(
+        self,
+        *,
+        topic: _ITopic_ef0ebe0e,
+        encoding: typing.Optional["EmailEncoding"] = None,
+    ) -> None:
         """Construction properties for a SNS action.
 
         :param topic: The SNS topic to notify.
@@ -613,9 +759,10 @@ class SnsProps():
         :stability: experimental
         """
         self._values = {
-            'topic': topic,
+            "topic": topic,
         }
-        if encoding is not None: self._values["encoding"] = encoding
+        if encoding is not None:
+            self._values["encoding"] = encoding
 
     @builtins.property
     def topic(self) -> _ITopic_ef0ebe0e:
@@ -624,7 +771,7 @@ class SnsProps():
         stability
         :stability: experimental
         """
-        return self._values.get('topic')
+        return self._values.get("topic")
 
     @builtins.property
     def encoding(self) -> typing.Optional["EmailEncoding"]:
@@ -636,7 +783,7 @@ class SnsProps():
         stability
         :stability: experimental
         """
-        return self._values.get('encoding')
+        return self._values.get("encoding")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -645,17 +792,22 @@ class SnsProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'SnsProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "SnsProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(_IReceiptRuleAction_cc1b8803)
-class Stop(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.Stop"):
+class Stop(
+    metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_actions.Stop"
+):
     """Terminates the evaluation of the receipt rule set and optionally publishes a notification to Amazon SNS.
 
     stability
     :stability: experimental
     """
-    def __init__(self, *, topic: typing.Optional[_ITopic_ef0ebe0e]=None) -> None:
+
+    def __init__(self, *, topic: typing.Optional[_ITopic_ef0ebe0e] = None) -> None:
         """
         :param topic: The SNS topic to notify when the stop action is taken.
 
@@ -678,9 +830,13 @@ class Stop(metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_ses_action
         return jsii.invoke(self, "bind", [_rule])
 
 
-@jsii.data_type(jsii_type="monocdk-experiment.aws_ses_actions.StopProps", jsii_struct_bases=[], name_mapping={'topic': 'topic'})
-class StopProps():
-    def __init__(self, *, topic: typing.Optional[_ITopic_ef0ebe0e]=None) -> None:
+@jsii.data_type(
+    jsii_type="monocdk-experiment.aws_ses_actions.StopProps",
+    jsii_struct_bases=[],
+    name_mapping={"topic": "topic"},
+)
+class StopProps:
+    def __init__(self, *, topic: typing.Optional[_ITopic_ef0ebe0e] = None) -> None:
         """Construction properties for a stop action.
 
         :param topic: The SNS topic to notify when the stop action is taken.
@@ -688,9 +844,9 @@ class StopProps():
         stability
         :stability: experimental
         """
-        self._values = {
-        }
-        if topic is not None: self._values["topic"] = topic
+        self._values = {}
+        if topic is not None:
+            self._values["topic"] = topic
 
     @builtins.property
     def topic(self) -> typing.Optional[_ITopic_ef0ebe0e]:
@@ -699,7 +855,7 @@ class StopProps():
         stability
         :stability: experimental
         """
-        return self._values.get('topic')
+        return self._values.get("topic")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -708,7 +864,9 @@ class StopProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'StopProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "StopProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
