@@ -14,8 +14,6 @@ from .. import (
     CfnResource as _CfnResource_7760e8e4,
     Construct as _Construct_f50a3f53,
     IResolvable as _IResolvable_9ceae33e,
-    FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1,
-    ICfnFinder as _ICfnFinder_3b168f30,
     TreeInspector as _TreeInspector_154f5999,
     IInspectable as _IInspectable_051e6ed8,
 )
@@ -61,34 +59,6 @@ class CfnByteMatchSet(
 
         jsii.create(CfnByteMatchSet, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnByteMatchSet":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -434,34 +404,6 @@ class CfnIPSet(
 
         jsii.create(CfnIPSet, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnIPSet":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -714,34 +656,6 @@ class CfnRule(
 
         jsii.create(CfnRule, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnRule":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -1020,34 +934,6 @@ class CfnSizeConstraintSet(
 
         jsii.create(CfnSizeConstraintSet, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnSizeConstraintSet":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -1371,34 +1257,6 @@ class CfnSqlInjectionMatchSet(
 
         jsii.create(CfnSqlInjectionMatchSet, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnSqlInjectionMatchSet":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -1721,34 +1579,6 @@ class CfnWebACL(
 
         jsii.create(CfnWebACL, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnWebACL":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -2110,34 +1940,6 @@ class CfnXssMatchSet(
 
         jsii.create(CfnXssMatchSet, self, [scope, id, props])
 
-    @jsii.member(jsii_name="fromCloudFormation")
-    @builtins.classmethod
-    def from_cloud_formation(
-        cls,
-        scope: _Construct_f50a3f53,
-        id: str,
-        resource_attributes: typing.Any,
-        *,
-        finder: _ICfnFinder_3b168f30,
-    ) -> "CfnXssMatchSet":
-        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
-
-        Used in the @aws-cdk/cloudformation-include module.
-
-        :param scope: -
-        :param id: -
-        :param resource_attributes: -
-        :param finder: The finder interface used to resolve references across the template.
-
-        stability
-        :stability: experimental
-        """
-        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
-
-        return jsii.sinvoke(
-            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
-        )
-
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: _TreeInspector_154f5999) -> None:
         """Examines the CloudFormation resource and discloses attributes.
