@@ -14,9 +14,11 @@ from .. import (
     CfnElement as _CfnElement_54343cf1,
     Construct as _Construct_f50a3f53,
     CfnCondition as _CfnCondition_548166d0,
+    CfnMapping as _CfnMapping_b46343a2,
     CfnOutput as _CfnOutput_1185605a,
     CfnParameter as _CfnParameter_90f1d0df,
     CfnResource as _CfnResource_7760e8e4,
+    CfnRule as _CfnRule_a373f272,
     NestedStack as _NestedStack_e205561c,
 )
 
@@ -42,18 +44,22 @@ class CfnInclude(
         *,
         template_file: str,
         nested_stacks: typing.Optional[typing.Mapping[str, "CfnIncludeProps"]] = None,
+        parameters: typing.Optional[typing.Mapping[str, typing.Any]] = None,
     ) -> None:
         """
         :param scope: -
         :param id: -
         :param template_file: Path to the template file. Both JSON and YAML template formats are supported.
-        :param nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from {@link CfnInclude.getNestedStack}. If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown.
+        :param nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from {@link CfnInclude.getNestedStack}. If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
+        :param parameters: Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. Default: - no parameters will be replaced
 
         stability
         :stability: experimental
         """
         props = CfnIncludeProps(
-            template_file=template_file, nested_stacks=nested_stacks
+            template_file=template_file,
+            nested_stacks=nested_stacks,
+            parameters=parameters,
         )
 
         jsii.create(CfnInclude, self, [scope, id, props])
@@ -74,11 +80,28 @@ class CfnInclude(
         """
         return jsii.invoke(self, "getCondition", [condition_name])
 
+    @jsii.member(jsii_name="getMapping")
+    def get_mapping(self, mapping_name: str) -> _CfnMapping_b46343a2:
+        """Returns the CfnMapping object from the 'Mappings' section of the included template.
+
+        Any modifications performed on that object will be reflected in the resulting CDK template.
+
+        If a Mapping with the given name is not present in the template,
+        an exception will be thrown.
+
+        :param mapping_name: the name of the Mapping in the template to retrieve.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "getMapping", [mapping_name])
+
     @jsii.member(jsii_name="getNestedStack")
     def get_nested_stack(self, logical_id: str) -> "IncludedNestedStack":
         """Returns the NestedStack with name logicalId.
 
         For a nested stack to be returned by this method, it must be specified in the {@link CfnIncludeProps.nestedStacks}
+        property.
 
         :param logical_id: the ID of the stack to retrieve, as it appears in the template.
 
@@ -89,7 +112,9 @@ class CfnInclude(
 
     @jsii.member(jsii_name="getOutput")
     def get_output(self, logical_id: str) -> _CfnOutput_1185605a:
-        """Returns the CfnOutput object from the 'Outputs' section of the included template Any modifications performed on that object will be reflected in the resulting CDK template.
+        """Returns the CfnOutput object from the 'Outputs' section of the included template.
+
+        Any modifications performed on that object will be reflected in the resulting CDK template.
 
         If an Output with the given name is not present in the template,
         throws an exception.
@@ -103,7 +128,9 @@ class CfnInclude(
 
     @jsii.member(jsii_name="getParameter")
     def get_parameter(self, parameter_name: str) -> _CfnParameter_90f1d0df:
-        """Returns the CfnParameter object from the 'Parameters' section of the included template Any modifications performed on that object will be reflected in the resulting CDK template.
+        """Returns the CfnParameter object from the 'Parameters' section of the included template.
+
+        Any modifications performed on that object will be reflected in the resulting CDK template.
 
         If a Parameter with the given name is not present in the template,
         throws an exception.
@@ -138,11 +165,31 @@ class CfnInclude(
         """
         return jsii.invoke(self, "getResource", [logical_id])
 
+    @jsii.member(jsii_name="getRule")
+    def get_rule(self, rule_name: str) -> _CfnRule_a373f272:
+        """Returns the CfnRule object from the 'Rules' section of the CloudFormation template with the given name.
+
+        Any modifications performed on that object will be reflected in the resulting CDK template.
+
+        If a Rule with the given name is not present in the template,
+        an exception will be thrown.
+
+        :param rule_name: the name of the Rule in the CloudFormation template.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "getRule", [rule_name])
+
 
 @jsii.data_type(
     jsii_type="monocdk-experiment.cloudformation_include.CfnIncludeProps",
     jsii_struct_bases=[],
-    name_mapping={"template_file": "templateFile", "nested_stacks": "nestedStacks"},
+    name_mapping={
+        "template_file": "templateFile",
+        "nested_stacks": "nestedStacks",
+        "parameters": "parameters",
+    },
 )
 class CfnIncludeProps:
     def __init__(
@@ -150,11 +197,13 @@ class CfnIncludeProps:
         *,
         template_file: str,
         nested_stacks: typing.Optional[typing.Mapping[str, "CfnIncludeProps"]] = None,
+        parameters: typing.Optional[typing.Mapping[str, typing.Any]] = None,
     ) -> None:
         """Construction properties of {@link CfnInclude}.
 
         :param template_file: Path to the template file. Both JSON and YAML template formats are supported.
-        :param nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from {@link CfnInclude.getNestedStack}. If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown.
+        :param nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from {@link CfnInclude.getNestedStack}. If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
+        :param parameters: Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. Default: - no parameters will be replaced
 
         stability
         :stability: experimental
@@ -164,6 +213,8 @@ class CfnIncludeProps:
         }
         if nested_stacks is not None:
             self._values["nested_stacks"] = nested_stacks
+        if parameters is not None:
+            self._values["parameters"] = parameters
 
     @builtins.property
     def template_file(self) -> str:
@@ -187,11 +238,30 @@ class CfnIncludeProps:
         or is in the template but is not a nested stack,
         template creation will fail and an error will be thrown.
 
+        default
+        :default: - no nested stacks will be included
+
         stability
         :stability: experimental
         """
         return self._values.get("nested_stacks")
 
+    @builtins.property
+    def parameters(self) -> typing.Optional[typing.Mapping[str, typing.Any]]:
+        """Specifies parameters to be replaced by the values in this mapping.
+
+        Any parameters in the template that aren't specified here will be left unmodified.
+        If you include a parameter here with an ID that isn't in the template,
+        template creation will fail and an error will be thrown.
+
+        default
+        :default: - no parameters will be replaced
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("parameters")
+
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
