@@ -50,6 +50,7 @@ class AwsCustomResource(
         id: str,
         *,
         policy: "AwsCustomResourcePolicy",
+        install_latest_aws_sdk: typing.Optional[bool] = None,
         log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
         on_create: typing.Optional["AwsSdkCall"] = None,
         on_delete: typing.Optional["AwsSdkCall"] = None,
@@ -62,6 +63,7 @@ class AwsCustomResource(
         :param scope: -
         :param id: -
         :param policy: The policy that will be added to the execution role of the Lambda function implementing this custom resource provider. The custom resource also implements ``iam.IGrantable``, making it possible to use the ``grantXxx()`` methods. As this custom resource uses a singleton Lambda function, it's important to note the that function's role will eventually accumulate the permissions/grants from all resources.
+        :param install_latest_aws_sdk: Whether to install the latest AWS SDK v2. Allows to use the latest API calls documented at https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html. The installation takes around 60 seconds. Default: true
         :param log_retention: The number of days log events of the Lambda function implementing this custom resource are kept in CloudWatch Logs. Default: logs.RetentionDays.INFINITE
         :param on_create: The AWS SDK call to make when the resource is created. Default: - the call when the resource is updated
         :param on_delete: The AWS SDK call to make when the resource is deleted. Default: - no call
@@ -75,6 +77,7 @@ class AwsCustomResource(
         """
         props = AwsCustomResourceProps(
             policy=policy,
+            install_latest_aws_sdk=install_latest_aws_sdk,
             log_retention=log_retention,
             on_create=on_create,
             on_delete=on_delete,
@@ -212,6 +215,7 @@ class AwsCustomResourcePolicy(
     jsii_struct_bases=[],
     name_mapping={
         "policy": "policy",
+        "install_latest_aws_sdk": "installLatestAwsSdk",
         "log_retention": "logRetention",
         "on_create": "onCreate",
         "on_delete": "onDelete",
@@ -226,6 +230,7 @@ class AwsCustomResourceProps:
         self,
         *,
         policy: "AwsCustomResourcePolicy",
+        install_latest_aws_sdk: typing.Optional[bool] = None,
         log_retention: typing.Optional[_RetentionDays_bdc7ad1f] = None,
         on_create: typing.Optional["AwsSdkCall"] = None,
         on_delete: typing.Optional["AwsSdkCall"] = None,
@@ -239,6 +244,7 @@ class AwsCustomResourceProps:
         Note that at least onCreate, onUpdate or onDelete must be specified.
 
         :param policy: The policy that will be added to the execution role of the Lambda function implementing this custom resource provider. The custom resource also implements ``iam.IGrantable``, making it possible to use the ``grantXxx()`` methods. As this custom resource uses a singleton Lambda function, it's important to note the that function's role will eventually accumulate the permissions/grants from all resources.
+        :param install_latest_aws_sdk: Whether to install the latest AWS SDK v2. Allows to use the latest API calls documented at https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html. The installation takes around 60 seconds. Default: true
         :param log_retention: The number of days log events of the Lambda function implementing this custom resource are kept in CloudWatch Logs. Default: logs.RetentionDays.INFINITE
         :param on_create: The AWS SDK call to make when the resource is created. Default: - the call when the resource is updated
         :param on_delete: The AWS SDK call to make when the resource is deleted. Default: - no call
@@ -259,6 +265,8 @@ class AwsCustomResourceProps:
         self._values = {
             "policy": policy,
         }
+        if install_latest_aws_sdk is not None:
+            self._values["install_latest_aws_sdk"] = install_latest_aws_sdk
         if log_retention is not None:
             self._values["log_retention"] = log_retention
         if on_create is not None:
@@ -292,6 +300,20 @@ class AwsCustomResourceProps:
         """
         return self._values.get("policy")
 
+    @builtins.property
+    def install_latest_aws_sdk(self) -> typing.Optional[bool]:
+        """Whether to install the latest AWS SDK v2. Allows to use the latest API calls documented at https://docs.aws.amazon.com/AWSJavaScriptSDK/latest/index.html.
+
+        The installation takes around 60 seconds.
+
+        default
+        :default: true
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get("install_latest_aws_sdk")
+
     @builtins.property
     def log_retention(self) -> typing.Optional[_RetentionDays_bdc7ad1f]:
         """The number of days log events of the Lambda function implementing this custom resource are kept in CloudWatch Logs.
