@@ -173,6 +173,16 @@ class FactName(
         """
         return jsii.sget(cls, "CDK_METADATA_RESOURCE_AVAILABLE")
 
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="DLC_REPOSITORY_ACCOUNT")
+    def DLC_REPOSITORY_ACCOUNT(cls) -> str:
+        """The ID of the AWS account that owns the public ECR repository that contains the AWS Deep Learning Containers images in a given region.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.sget(cls, "DLC_REPOSITORY_ACCOUNT")
+
     @jsii.python.classproperty
     @jsii.member(jsii_name="DOMAIN_SUFFIX")
     def DOMAIN_SUFFIX(cls) -> str:
@@ -342,6 +352,24 @@ class RegionInfo(
         """
         return jsii.sinvoke(cls, "get", [name])
 
+    @jsii.member(jsii_name="regionMap")
+    @builtins.classmethod
+    def region_map(cls, fact_name: str) -> typing.Mapping[str, str]:
+        """Retrieves a collection of all fact values for all regions that fact is defined in.
+
+        :param fact_name: the name of the fact to retrieve values for. For a list of common fact names, see the FactName class
+
+        return
+        :return:
+
+        a mapping with AWS region codes as the keys,
+        and the fact in the given region as the value for that key
+
+        stability
+        :stability: experimental
+        """
+        return jsii.sinvoke(cls, "regionMap", [fact_name])
+
     @jsii.member(jsii_name="servicePrincipal")
     def service_principal(self, service: str) -> typing.Optional[str]:
         """The name of the service principal for a given service in this region.
@@ -387,6 +415,16 @@ class RegionInfo(
         """
         return jsii.get(self, "name")
 
+    @builtins.property
+    @jsii.member(jsii_name="dlcRepositoryAccount")
+    def dlc_repository_account(self) -> typing.Optional[str]:
+        """The ID of the AWS account that owns the public ECR repository containing the AWS Deep Learning Containers images in this region.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "dlcRepositoryAccount")
+
     @builtins.property
     @jsii.member(jsii_name="domainSuffix")
     def domain_suffix(self) -> typing.Optional[str]:
